"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtXml import *
import enum


class QDomNode(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qdomnode.html

    **Detailed Description**

    Many functions in the DOM return a QDomNode.

    You can find out the type of a node using **isAttr** (), **isCDATASection**
    (), **isDocumentFragment** (), **isDocument** (), **isDocumentType** (),
    **isElement** (), **isEntityReference** (), **isText** (), **isEntity** (),
    **isNotation** (), **isProcessingInstruction** (), **isCharacterData** ()
    and **isComment** ().

    A QDomNode can be converted into one of its subclasses using **toAttr** (),
    **toCDATASection** (), **toDocumentFragment** (), **toDocument** (),
    **toDocumentType** (), **toElement** (), **toEntityReference** (),
    **toText** (), **toEntity** (), **toNotation** (),
    **toProcessingInstruction** (), **toCharacterData** () or **toComment** ().
    You can convert a node to a null node with **clear** ().

    Copies of the QDomNode class share their data using explicit sharing. This
    means that modifying one node will change all copies. This is especially
    useful in combination with functions which return a QDomNode, e.g.
    **firstChild** (). You can make an independent (deep) copy of the node with
    **cloneNode** ().

    A QDomNode can be null, much like `nullptr`. Creating a copy of a null node
    results in another null node. It is not possible to modify a null node, but
    it is possible to assign another, possibly non-null node to it. In this
    case, the copy of the null node will remain null. You can check if a
    QDomNode is null by calling **isNull** (). The empty constructor of a
    QDomNode (or any of the derived classes) creates a null node.

    Nodes are inserted with **insertBefore** (), **insertAfter** () or
    **appendChild** (). You can replace one node with another using
    **replaceChild** () and remove a node with **removeChild** ().

    To traverse nodes use **firstChild** () to get a node's first child (if
    any), and **nextSibling** () to traverse. QDomNode also provides
    **lastChild** (), **previousSibling** () and **parentNode** (). To find the
    first child node with a particular node name use **namedItem** ().

    To find out if a node has children use **hasChildNodes** () and to get a
    list of all of a node's children use **childNodes** ().

    The node's name and value (the meaning of which varies depending on its
    type) is returned by **nodeName** () and **nodeValue** () respectively. The
    node's type is returned by **nodeType** (). The node's value can be set with
    **setNodeValue** ().

    The document to which the node belongs is returned by **ownerDocument** ().

    Adjacent **QDomText**  nodes can be merged into a single node with
    **normalize** ().

    **QDomElement**  nodes have attributes which can be retrieved with
    **attributes** ().

    **QDomElement**  and **QDomAttr**  nodes can have namespaces which can be
    retrieved with **namespaceURI** (). Their local name is retrieved with
    **localName** (), and their prefix with **prefix** (). The prefix can be set
    with **setPrefix** ().

    You can write the XML representation of the node to a text stream with
    **save** ().

    The following example looks for the first element in an XML document and
    prints the names of all the elements that are its direct children.

    **QDomDocument**  d;
        **QString**  someXML;
    d.setContent(someXML);
        **QDomNode**  n = d.firstChild();
        while
    (!n.isNull()) {
            if (n.isElement()) {
                **QDomElement**  e
    = n.toElement();
                cout << "Element name: " << **qPrintable**
    (e.tagName()) << '\\n';
                break;
            }
            n =
    n.nextSibling();
        }

    For further information about the Document Object Model see **Level 1**  and
    **Level 2 Core** . For a more general introduction of the DOM implementation
    see the **QDomDocument**  documentation.
    """

    class EncodingPolicy(enum.Enum):
        EncodingFromDocument: QDomNode = ...
        EncodingFromTextStream: QDomNode = ...

    class NodeType(enum.Enum):
        ElementNode: QDomNode = ...
        AttributeNode: QDomNode = ...
        TextNode: QDomNode = ...
        CDATASectionNode: QDomNode = ...
        EntityReferenceNode: QDomNode = ...
        EntityNode: QDomNode = ...
        ProcessingInstructionNode: QDomNode = ...
        CommentNode: QDomNode = ...
        DocumentNode: QDomNode = ...
        DocumentTypeNode: QDomNode = ...
        DocumentFragmentNode: QDomNode = ...
        NotationNode: QDomNode = ...
        BaseNode: QDomNode = ...
        CharacterDataNode: QDomNode = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qdomnode.html#QDomNode

        **QDomNode::QDomNode()**

        Constructs a **null**  node.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QDomNode") -> None:
        """
        https://doc.qt.io/qt-6/qdomnode.html#QDomNode-1

        **QDomNode::QDomNode(const QDomNode & n )**

        Constructs a copy of **n**.

        The data of the copy is shared (shallow copy): modifying one node will
        also change the other. If you want to make a deep copy, use
        **cloneNode** ().
        """
        ...

    def columnNumber(self) -> int:
        """
        https://doc.qt.io/qt-6/qdomnode.html#columnNumber

        **int QDomNode::columnNumber() const**

        For nodes created by **QDomDocument::setContent** (), this function
        returns the column number in the XML document where the node was parsed.
        Otherwise, -1 is returned.

        **See also** **lineNumber** () and **QDomDocument::setContent** ().
        """
        ...

    def lineNumber(self) -> int:
        """
        https://doc.qt.io/qt-6/qdomnode.html#lineNumber

        **int QDomNode::lineNumber() const**

        For nodes created by **QDomDocument::setContent** (), this function
        returns the line number in the XML document where the node was parsed.
        Otherwise, -1 is returned.

        **See also** **columnNumber** () and **QDomDocument::setContent** ().
        """
        ...

    def nextSiblingElement(
        self, taName: str = ..., namespaceURI: str = ...
    ) -> "QDomElement":
        """
        https://doc.qt.io/qt-6/qdomnode.html#nextSiblingElement

        **QDomElement QDomNode::nextSiblingElement(const QString & tagName =
        QString(), const QString & namespaceURI = QString()) const**

        Returns the next sibling element with tag name **tagName** and namespace
        URI **namespaceURI**. If **tagName** is empty, returns the next sibling
        element with **namespaceURI** , and if **namespaceURI** is empty,
        returns the next sibling child element with **tagName**. If the both
        parameters are empty, returns the next sibling element. Returns a null
        element if no such sibling exists.

        **See also** **firstChildElement** (), **previousSiblingElement** (),
        and **lastChildElement** ().
        """
        ...

    def previousSiblingElement(
        self, tagName: str = ..., namespaceURI: str = ...
    ) -> "QDomElement":
        """
        https://doc.qt.io/qt-6/qdomnode.html#previousSiblingElement

        **QDomElement QDomNode::previousSiblingElement(const QString & tagName =
        QString(), const QString & namespaceURI = QString()) const**

        Returns the previous sibling element with tag name **tagName** and
        namespace URI **namespaceURI**. If **tagName** is empty, returns the
        previous sibling element with **namespaceURI** , and if **namespaceURI**
        is empty, returns the previous sibling element with **tagName**. If the
        both parameters are empty, returns the previous sibling element. Returns
        a null element if no such sibling exists.

        **See also** **firstChildElement** (), **nextSiblingElement** (), and
        **lastChildElement** ().
        """
        ...

    def lastChildElement(
        self, tagName: str = ..., namespaceURI: str = ...
    ) -> "QDomElement":
        """
        https://doc.qt.io/qt-6/qdomnode.html#lastChildElement

        **QDomElement QDomNode::lastChildElement(const QString & tagName =
        QString(), const QString & namespaceURI = QString()) const**

        Returns the last child element with tag name **tagName** and namespace
        URI **namespaceURI**. If **tagName** is empty, returns the last child
        element with **namespaceURI** , and if **namespaceURI** is empty,
        returns the last child element with **tagName**. If the both parameters
        are empty, returns the last child element. Returns a null element if no
        such child exists.

        **See also** **firstChildElement** (), **previousSiblingElement** (),
        and **nextSiblingElement** ().
        """
        ...

    def firstChildElement(
        self, tagName: str = ..., namespaceURI: str = ...
    ) -> "QDomElement":
        """
        https://doc.qt.io/qt-6/qdomnode.html#firstChildElement

        **QDomElement QDomNode::firstChildElement(const QString & tagName =
        QString(), const QString & namespaceURI = QString()) const**

        Returns the first child element with tag name **tagName** and namespace
        URI **namespaceURI**. If **tagName** is empty, returns the first child
        element with **namespaceURI** , and if **namespaceURI** is empty,
        returns the first child element with **tagName**. If the both parameters
        are empty, returns the first child element. Returns a null element if no
        such child exists.

        **See also** **lastChildElement** (), **previousSiblingElement** (), and
        **nextSiblingElement** ().
        """
        ...

    def save(
        self, a0: QtCore.QTextStream, a1: int, a2: "QDomNode.EncodingPolicy" = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdomnode.html#save

        **void QDomNode::save(QTextStream & stream , int indent ,
        QDomNode::EncodingPolicy encodingPolicy =
        QDomNode::EncodingFromDocument) const**

        Writes the XML representation of the node and all its children to the
        stream **stream**. This function uses **indent** as the amount of space
        to indent the node.

        If the document contains invalid XML characters or characters that
        cannot be encoded in the given encoding, the result and behavior is
        undefined.

        If **encodingPolicy** is **QDomNode::EncodingFromDocument**  and this
        node is a document node, the encoding of text stream **stream** 's
        encoding is set by treating a processing instruction by name "xml" as an
        XML declaration, if one exists, and otherwise defaults to UTF-8. XML
        declarations are not processing instructions, but this behavior exists
        for historical reasons. If this node is not a document node, the text
        stream's encoding is used.

        If **encodingPolicy** is **EncodingFromTextStream**  and this node is a
        document node, this function behaves as save(**QTextStream**  &str, int
        indent) with the exception that the encoding specified in the text
        stream **stream** is used.

        If the document contains invalid XML characters or characters that
        cannot be encoded in the given encoding, the result and behavior is
        undefined.
        """
        ...

    def toComment(self) -> "QDomComment":
        """
        https://doc.qt.io/qt-6/qdomnode.html#toComment

        **QDomComment QDomNode::toComment() const**

        Converts a **QDomNode**  into a **QDomComment** . If the node is not a
        comment the returned object will be **null** .

        **See also** **isComment** ().
        """
        ...

    def toCharacterData(self) -> "QDomCharacterData":
        """
        https://doc.qt.io/qt-6/qdomnode.html#toCharacterData

        **QDomCharacterData QDomNode::toCharacterData() const**

        Converts a **QDomNode**  into a **QDomCharacterData** . If the node is
        not a character data node the returned object will be **null** .

        **See also** **isCharacterData** ().
        """
        ...

    def toProcessingInstruction(self) -> "QDomProcessingInstruction":
        """
        https://doc.qt.io/qt-6/qdomnode.html#toProcessingInstruction

        **QDomProcessingInstruction QDomNode::toProcessingInstruction() const**

        Converts a **QDomNode**  into a **QDomProcessingInstruction** . If the
        node is not a processing instruction the returned object will be
        **null** .

        **See also** **isProcessingInstruction** ().
        """
        ...

    def toNotation(self) -> "QDomNotation":
        """
        https://doc.qt.io/qt-6/qdomnode.html#toNotation

        **QDomNotation QDomNode::toNotation() const**

        Converts a **QDomNode**  into a **QDomNotation** . If the node is not a
        notation the returned object will be **null** .

        **See also** **isNotation** ().
        """
        ...

    def toEntity(self) -> "QDomEntity":
        """
        https://doc.qt.io/qt-6/qdomnode.html#toEntity

        **QDomEntity QDomNode::toEntity() const**

        Converts a **QDomNode**  into a **QDomEntity** . If the node is not an
        entity the returned object will be **null** .

        **See also** **isEntity** ().
        """
        ...

    def toText(self) -> "QDomText":
        """
        https://doc.qt.io/qt-6/qdomnode.html#toText

        **QDomText QDomNode::toText() const**

        Converts a **QDomNode**  into a **QDomText** . If the node is not a
        text, the returned object will be **null** .

        **See also** **isText** ().
        """
        ...

    def toEntityReference(self) -> "QDomEntityReference":
        """
        https://doc.qt.io/qt-6/qdomnode.html#toEntityReference

        **QDomEntityReference QDomNode::toEntityReference() const**

        Converts a **QDomNode**  into a **QDomEntityReference** . If the node is
        not an entity reference, the returned object will be **null** .

        **See also** **isEntityReference** ().
        """
        ...

    def toElement(self) -> "QDomElement":
        """
        https://doc.qt.io/qt-6/qdomnode.html#toElement

        **QDomElement QDomNode::toElement() const**

        Converts a **QDomNode**  into a **QDomElement** . If the node is not an
        element the returned object will be **null** .

        **See also** **isElement** ().
        """
        ...

    def toDocumentType(self) -> "QDomDocumentType":
        """
        https://doc.qt.io/qt-6/qdomnode.html#toDocumentType

        **QDomDocumentType QDomNode::toDocumentType() const**

        Converts a **QDomNode**  into a **QDomDocumentType** . If the node is
        not a document type the returned object will be **null** .

        **See also** **isDocumentType** ().
        """
        ...

    def toDocument(self) -> "QDomDocument":
        """
        https://doc.qt.io/qt-6/qdomnode.html#toDocument

        **QDomDocument QDomNode::toDocument() const**

        Converts a **QDomNode**  into a **QDomDocument** . If the node is not a
        document the returned object will be **null** .

        **See also** **isDocument** ().
        """
        ...

    def toDocumentFragment(self) -> "QDomDocumentFragment":
        """
        https://doc.qt.io/qt-6/qdomnode.html#toDocumentFragment

        **QDomDocumentFragment QDomNode::toDocumentFragment() const**

        Converts a **QDomNode**  into a **QDomDocumentFragment** . If the node
        is not a document fragment the returned object will be **null** .

        **See also** **isDocumentFragment** ().
        """
        ...

    def toCDATASection(self) -> "QDomCDATASection":
        """
        https://doc.qt.io/qt-6/qdomnode.html#toCDATASection

        **QDomCDATASection QDomNode::toCDATASection() const**

        Converts a **QDomNode**  into a **QDomCDATASection** . If the node is
        not a CDATA section, the returned object will be **null** .

        **See also** **isCDATASection** ().
        """
        ...

    def toAttr(self) -> "QDomAttr":
        """
        https://doc.qt.io/qt-6/qdomnode.html#toAttr

        **QDomAttr QDomNode::toAttr() const**

        Converts a **QDomNode**  into a **QDomAttr** . If the node is not an
        attribute, the returned object will be **null** .

        **See also** **isAttr** ().
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qdomnode.html#clear

        **void QDomNode::clear()**

        Converts the node into a null node; if it was not a null node before,
        its type and contents are deleted.

        **See also** **isNull** ().
        """
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdomnode.html#isNull

        **bool QDomNode::isNull() const**

        Returns `true` if this node is null (i.e. if it has no type or
        contents); otherwise returns `false`.
        """
        ...

    def namedItem(self, name: str) -> "QDomNode":
        """
        https://doc.qt.io/qt-6/qdomnode.html#namedItem

        **QDomNode QDomNode::namedItem(const QString & name ) const**

        Returns the first direct child node for which **nodeName** () equals
        **name**.

        If no such direct child exists, a **null node**  is returned.

        **See also** **nodeName** ().
        """
        ...

    def isComment(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdomnode.html#isComment

        **bool QDomNode::isComment() const**

        Returns `true` if the node is a comment; otherwise returns `false`.

        If this function returns `true`, it does not imply that this object is a
        **QDomComment** ; you can get the **QDomComment**  with **toComment**
        ().

        **See also** **toComment** ().
        """
        ...

    def isCharacterData(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdomnode.html#isCharacterData

        **bool QDomNode::isCharacterData() const**

        Returns `true` if the node is a character data node; otherwise returns
        `false`.

        If this function returns `true`, it does not imply that this object is a
        **QDomCharacterData** ; you can get the **QDomCharacterData**  with
        **toCharacterData** ().

        **See also** **toCharacterData** ().
        """
        ...

    def isProcessingInstruction(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdomnode.html#isProcessingInstruction

        **bool QDomNode::isProcessingInstruction() const**

        Returns `true` if the node is a processing instruction; otherwise
        returns `false`.

        If this function returns `true`, it does not imply that this object is a
        **QDomProcessingInstruction** ; you can get the QProcessingInstruction
        with **toProcessingInstruction** ().

        **See also** **toProcessingInstruction** ().
        """
        ...

    def isNotation(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdomnode.html#isNotation

        **bool QDomNode::isNotation() const**

        Returns `true` if the node is a notation; otherwise returns `false`.

        If this function returns `true`, it does not imply that this object is a
        **QDomNotation** ; you can get the **QDomNotation**  with **toNotation**
        ().

        **See also** **toNotation** ().
        """
        ...

    def isEntity(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdomnode.html#isEntity

        **bool QDomNode::isEntity() const**

        Returns `true` if the node is an entity; otherwise returns `false`.

        If this function returns `true`, it does not imply that this object is a
        **QDomEntity** ; you can get the **QDomEntity**  with **toEntity** ().

        **See also** **toEntity** ().
        """
        ...

    def isText(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdomnode.html#isText

        **bool QDomNode::isText() const**

        Returns `true` if the node is a text node; otherwise returns `false`.

        If this function returns `true`, it does not imply that this object is a
        **QDomText** ; you can get the **QDomText**  with **toText** ().

        **See also** **toText** ().
        """
        ...

    def isEntityReference(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdomnode.html#isEntityReference

        **bool QDomNode::isEntityReference() const**

        Returns `true` if the node is an entity reference; otherwise returns
        false.

        If this function returns `true`, it does not imply that this object is a
        **QDomEntityReference** ; you can get the **QDomEntityReference**  with
        **toEntityReference** ().

        **See also** **toEntityReference** ().
        """
        ...

    def isElement(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdomnode.html#isElement

        **bool QDomNode::isElement() const**

        Returns `true` if the node is an element; otherwise returns `false`.

        If this function returns `true`, it does not imply that this object is a
        **QDomElement** ; you can get the **QDomElement**  with **toElement**
        ().

        **See also** **toElement** ().
        """
        ...

    def isDocumentType(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdomnode.html#isDocumentType

        **bool QDomNode::isDocumentType() const**

        Returns `true` if the node is a document type; otherwise returns false.

        If this function returns `true`, it does not imply that this object is a
        **QDomDocumentType** ; you can get the **QDomDocumentType**  with
        **toDocumentType** ().

        **See also** **toDocumentType** ().
        """
        ...

    def isDocument(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdomnode.html#isDocument

        **bool QDomNode::isDocument() const**

        Returns `true` if the node is a document; otherwise returns `false`.

        If this function returns `true`, it does not imply that this object is a
        **QDomDocument** ; you can get the **QDomDocument**  with **toDocument**
        ().

        **See also** **toDocument** ().
        """
        ...

    def isDocumentFragment(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdomnode.html#isDocumentFragment

        **bool QDomNode::isDocumentFragment() const**

        Returns `true` if the node is a document fragment; otherwise returns
        false.

        If this function returns `true`, it does not imply that this object is a
        **QDomDocumentFragment** ; you can get the **QDomDocumentFragment**
        with **toDocumentFragment** ().

        **See also** **toDocumentFragment** ().
        """
        ...

    def isCDATASection(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdomnode.html#isCDATASection

        **bool QDomNode::isCDATASection() const**

        Returns `true` if the node is a CDATA section; otherwise returns false.

        If this function returns `true`, it does not imply that this object is a
        **QDomCDATASection** ; you can get the **QDomCDATASection**  with
        **toCDATASection** ().

        **See also** **toCDATASection** ().
        """
        ...

    def isAttr(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdomnode.html#isAttr

        **bool QDomNode::isAttr() const**

        Returns `true` if the node is an attribute; otherwise returns `false`.

        If this function returns `true`, it does not imply that this object is a
        QDomAttribute; you can get the QDomAttribute with toAttribute().

        **See also** **toAttr** ().
        """
        ...

    def setPrefix(self, pre: str) -> None:
        """
        https://doc.qt.io/qt-6/qdomnode.html#setPrefix

        **void QDomNode::setPrefix(const QString & pre )**

        If the node has a namespace prefix, this function changes the namespace
        prefix of the node to **pre**. Otherwise this function does nothing.

        Only nodes of type **ElementNode**  or **AttributeNode**  can have
        namespaces. A namespace prefix must have be specified at creation time;
        it is not possible to add a namespace prefix afterwards.

        **See also** **prefix** (), **localName** (), **namespaceURI** (),
        **QDomDocument::createElementNS** (), and
        **QDomDocument::createAttributeNS** ().
        """
        ...

    def prefix(self) -> str:
        """
        https://doc.qt.io/qt-6/qdomnode.html#prefix

        **QString QDomNode::prefix() const**

        Returns the namespace prefix of the node or an empty string if the node
        has no namespace prefix.

        Only nodes of type **ElementNode**  or **AttributeNode**  can have
        namespaces. A namespace prefix must be specified at creation time. If a
        node was created with a namespace prefix, you can change it later with
        **setPrefix** ().

        If you create an element or attribute with
        **QDomDocument::createElement** () or **QDomDocument::createAttribute**
        (), the prefix will be an empty string. If you use
        **QDomDocument::createElementNS** () or
        **QDomDocument::createAttributeNS** () instead, the prefix will not be
        an empty string; but it might be an empty string if the name does not
        have a prefix.

        **See also** **setPrefix** (), **localName** (), **namespaceURI** (),
        **QDomDocument::createElementNS** (), and
        **QDomDocument::createAttributeNS** ().
        """
        ...

    def setNodeValue(self, a0: str) -> None:
        """
        https://doc.qt.io/qt-6/qdomnode.html#setNodeValue

        **void QDomNode::setNodeValue(const QString & v )**

        Sets the node's value to **v**.

        **See also** **nodeValue** ().
        """
        ...

    def nodeValue(self) -> str:
        """
        https://doc.qt.io/qt-6/qdomnode.html#nodeValue

        **QString QDomNode::nodeValue() const**

        Returns the value of the node.

        The meaning of the value depends on the subclass:

        NameMeaning
        **QDomAttr** The attribute value
        **QDomCDATASection**
        The content of the CDATA section
        **QDomComment** The comment
        **QDomProcessingInstruction** The data of the processing instruction
        **QDomText** The text

        All the other subclasses do not have a node value and will return an
        empty string.

        **See also** **setNodeValue** () and **nodeName** ().
        """
        ...

    def hasAttributes(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdomnode.html#hasAttributes

        **bool QDomNode::hasAttributes() const**

        Returns `true` if the node has attributes; otherwise returns `false`.

        **See also** **attributes** ().
        """
        ...

    def localName(self) -> str:
        """
        https://doc.qt.io/qt-6/qdomnode.html#localName

        **QString QDomNode::localName() const**

        If the node uses namespaces, this function returns the local name of the
        node; otherwise it returns an empty string.

        Only nodes of type **ElementNode**  or **AttributeNode**  can have
        namespaces. A namespace must have been specified at creation time; it is
        not possible to add a namespace afterwards.

        **See also** **prefix** (), **namespaceURI** (),
        **QDomDocument::createElementNS** (), and
        **QDomDocument::createAttributeNS** ().
        """
        ...

    def namespaceURI(self) -> str:
        """
        https://doc.qt.io/qt-6/qdomnode.html#namespaceURI

        **QString QDomNode::namespaceURI() const**

        Returns the namespace URI of this node or an empty string if the node
        has no namespace URI.

        Only nodes of type **ElementNode**  or **AttributeNode**  can have
        namespaces. A namespace URI must be specified at creation time and
        cannot be changed later.

        **See also** **prefix** (), **localName** (),
        **QDomDocument::createElementNS** (), and
        **QDomDocument::createAttributeNS** ().
        """
        ...

    def ownerDocument(self) -> "QDomDocument":
        """
        https://doc.qt.io/qt-6/qdomnode.html#ownerDocument

        **QDomDocument QDomNode::ownerDocument() const**

        Returns the document to which this node belongs.
        """
        ...

    def attributes(self) -> "QDomNamedNodeMap":
        """
        https://doc.qt.io/qt-6/qdomnode.html#attributes

        **QDomNamedNodeMap QDomNode::attributes() const**

        Returns a named node map of all attributes. Attributes are only provided
        for **QDomElement** s.

        Changing the attributes in the map will also change the attributes of
        this **QDomNode** .
        """
        ...

    def nextSibling(self) -> "QDomNode":
        """
        https://doc.qt.io/qt-6/qdomnode.html#nextSibling

        **QDomNode QDomNode::nextSibling() const**

        Returns the next sibling in the document tree. Changing the returned
        node will also change the node in the document tree.

        If you have XML like this:

        <h1>Heading</h1>
            <p>The text...</p>
            <h2>Next heading</h2>

        and this **QDomNode**  represents the <p> tag, nextSibling() will return
        the node representing the <h2> tag.

        **See also** **previousSibling** ().
        """
        ...

    def previousSibling(self) -> "QDomNode":
        """
        https://doc.qt.io/qt-6/qdomnode.html#previousSibling

        **QDomNode QDomNode::previousSibling() const**

        Returns the previous sibling in the document tree. Changing the returned
        node will also change the node in the document tree.

        For example, if you have XML like this:

        <h1>Heading</h1>
            <p>The text...</p>
            <h2>Next heading</h2>

        and this **QDomNode**  represents the &lt;p&gt; tag, previousSibling()
        will return the node representing the &lt;h1&gt; tag.

        **See also** **nextSibling** ().
        """
        ...

    def lastChild(self) -> "QDomNode":
        """
        https://doc.qt.io/qt-6/qdomnode.html#lastChild

        **QDomNode QDomNode::lastChild() const**

        Returns the last child of the node. If there is no child node, a **null
        node**  is returned. Changing the returned node will also change the
        node in the document tree.

        **See also** **firstChild** () and **childNodes** ().
        """
        ...

    def firstChild(self) -> "QDomNode":
        """
        https://doc.qt.io/qt-6/qdomnode.html#firstChild

        **QDomNode QDomNode::firstChild() const**

        Returns the first child of the node. If there is no child node, a **null
        node**  is returned. Changing the returned node will also change the
        node in the document tree.

        **See also** **lastChild** () and **childNodes** ().
        """
        ...

    def childNodes(self) -> "QDomNodeList":
        """
        https://doc.qt.io/qt-6/qdomnode.html#childNodes

        **QDomNodeList QDomNode::childNodes() const**

        Returns a list of all direct child nodes.

        Most often you will call this function on a **QDomElement**  object.

        For example, if the XML document looks like this:

        <body>
            <h1>Heading</h1>
            <p>Hello <b>you</b></p>
            </body>

        Then the list of child nodes for the "body"-element will contain the
        node created by the &lt;h1&gt; tag and the node created by the &lt;p&gt;
        tag.

        The nodes in the list are not copied; so changing the nodes in the list
        will also change the children of this node.

        **See also** **firstChild** () and **lastChild** ().
        """
        ...

    def parentNode(self) -> "QDomNode":
        """
        https://doc.qt.io/qt-6/qdomnode.html#parentNode

        **QDomNode QDomNode::parentNode() const**

        Returns the parent node. If this node has no parent, a null node is
        returned (i.e. a node for which **isNull** () returns `true`).
        """
        ...

    def nodeType(self) -> "QDomNode.NodeType":
        """
        https://doc.qt.io/qt-6/qdomnode.html#nodeType

        **QDomNode::NodeType QDomNode::nodeType() const**

        Returns the type of the node.

        **See also** **toAttr** (), **toCDATASection** (),
        **toDocumentFragment** (), **toDocument** (), **toDocumentType** (),
        **toElement** (), **toEntityReference** (), **toText** (), **toEntity**
        (), **toNotation** (), **toProcessingInstruction** (),
        **toCharacterData** (), and **toComment** ().
        """
        ...

    def nodeName(self) -> str:
        """
        https://doc.qt.io/qt-6/qdomnode.html#nodeName

        **QString QDomNode::nodeName() const**

        Returns the name of the node.

        The meaning of the name depends on the subclass:

        NameMeaning
        **QDomAttr** The name of the attribute
        **QDomCDATASection** The string "#cdata-section"
        **QDomComment** The
        string "#comment"
        **QDomDocument** The string "#document"
        **QDomDocumentFragment** The string "#document-fragment"
        **QDomDocumentType** The name of the document type
        **QDomElement** The
        tag name
        **QDomEntity** The name of the entity
        **QDomEntityReference** The name of the referenced entity
        **QDomNotation** The name of the notation
        **QDomProcessingInstruction** The target of the processing instruction
        **QDomText** The string "#text"

        **Note:** This function does not take the presence of namespaces into
        account when processing the names of element and attribute nodes. As a
        result, the returned name can contain any namespace prefix that may be
        present. To obtain the node name of an element or attribute, use
        **localName** (); to obtain the namespace prefix, use **namespaceURI**
        ().

        **See also** **nodeValue** ().
        """
        ...

    def isSupported(self, feature: str, version: str) -> bool:
        """
        https://doc.qt.io/qt-6/qdomnode.html#isSupported

        **bool QDomNode::isSupported(const QString & feature , const QString &
        version ) const**

        Returns `true` if the DOM implementation implements the feature
        **feature** and this feature is supported by this node in the version
        **version** ; otherwise returns `false`.

        **See also** **QDomImplementation::hasFeature** ().
        """
        ...

    def normalize(self) -> None:
        """
        https://doc.qt.io/qt-6/qdomnode.html#normalize

        **void QDomNode::normalize()**

        Calling normalize() on an element converts all its children into a
        standard form. This means that adjacent **QDomText**  objects will be
        merged into a single text object (**QDomCDATASection**  nodes are not
        merged).
        """
        ...

    def cloneNode(self, deep: bool = ...) -> "QDomNode":
        """
        https://doc.qt.io/qt-6/qdomnode.html#cloneNode

        **QDomNode QDomNode::cloneNode(bool deep = true) const**

        Creates a deep (not shallow) copy of the **QDomNode** .

        If **deep** is true, then the cloning is done recursively which means
        that all the node's children are deep copied too. If **deep** is false
        only the node itself is copied and the copy will have no child nodes.
        """
        ...

    def hasChildNodes(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdomnode.html#hasChildNodes

        **bool QDomNode::hasChildNodes() const**

        Returns `true` if the node has one or more children; otherwise returns
        `false`.
        """
        ...

    def appendChild(self, newChild: "QDomNode") -> "QDomNode":
        """
        https://doc.qt.io/qt-6/qdomnode.html#appendChild

        **QDomNode QDomNode::appendChild(const QDomNode & newChild )**

        Appends **newChild** as the node's last child.

        If **newChild** is the child of another node, it is reparented to this
        node. If **newChild** is a child of this node, then its position in the
        list of children is changed.

        If **newChild** is a **QDomDocumentFragment** , then the children of the
        fragment are removed from the fragment and appended.

        If **newChild** is a **QDomElement**  and this node is a
        **QDomDocument**  that already has an element node as a child,
        **newChild** is not added as a child and a null node is returned.

        Returns a new reference to **newChild** on success or a **null node**
        on failure.

        Calling this function on a null node(created, for example, with the
        default constructor) does nothing and returns a **null node** .

        The DOM specification disallow inserting attribute nodes, but for
        historical reasons, QDom accepts them anyway.

        **See also** **insertBefore** (), **insertAfter** (), **replaceChild**
        (), and **removeChild** ().
        """
        ...

    def removeChild(self, oldChild: "QDomNode") -> "QDomNode":
        """
        https://doc.qt.io/qt-6/qdomnode.html#removeChild

        **QDomNode QDomNode::removeChild(const QDomNode & oldChild )**

        Removes **oldChild** from the list of children. **oldChild** must be a
        direct child of this node.

        Returns a new reference to **oldChild** on success or a **null node**
        on failure.

        **See also** **insertBefore** (), **insertAfter** (), **replaceChild**
        (), and **appendChild** ().
        """
        ...

    def replaceChild(self, newChild: "QDomNode", oldChild: "QDomNode") -> "QDomNode":
        """
        https://doc.qt.io/qt-6/qdomnode.html#replaceChild

        **QDomNode QDomNode::replaceChild(const QDomNode & newChild , const
        QDomNode & oldChild )**

        Replaces **oldChild** with **newChild**. **oldChild** must be a direct
        child of this node.

        If **newChild** is the child of another node, it is reparented to this
        node. If **newChild** is a child of this node, then its position in the
        list of children is changed.

        If **newChild** is a **QDomDocumentFragment** , then **oldChild** is
        replaced by all of the children of the fragment.

        Returns a new reference to **oldChild** on success or a **null node**
        on failure.

        **See also** **insertBefore** (), **insertAfter** (), **removeChild**
        (), and **appendChild** ().
        """
        ...

    def insertAfter(self, newChild: "QDomNode", refChild: "QDomNode") -> "QDomNode":
        """
        https://doc.qt.io/qt-6/qdomnode.html#insertAfter

        **QDomNode QDomNode::insertAfter(const QDomNode & newChild , const
        QDomNode & refChild )**

        Inserts the node **newChild** after the child node **refChild**.
        **refChild** must be a direct child of this node. If **refChild** is
        **null**  then **newChild** is appended as this node's last child.

        If **newChild** is the child of another node, it is reparented to this
        node. If **newChild** is a child of this node, then its position in the
        list of children is changed.

        If **newChild** is a **QDomDocumentFragment** , then the children of the
        fragment are removed from the fragment and inserted after **refChild**.

        Returns a new reference to **newChild** on success or a **null node**
        on failure.

        The DOM specification disallow inserting attribute nodes, but due to
        historical reasons QDom accept them nevertheless.

        **See also** **insertBefore** (), **replaceChild** (), **removeChild**
        (), and **appendChild** ().
        """
        ...

    def insertBefore(self, newChild: "QDomNode", refChild: "QDomNode") -> "QDomNode":
        """
        https://doc.qt.io/qt-6/qdomnode.html#insertBefore

        **QDomNode QDomNode::insertBefore(const QDomNode & newChild , const
        QDomNode & refChild )**

        Inserts the node **newChild** before the child node **refChild**.
        **refChild** must be a direct child of this node. If **refChild** is
        **null**  then **newChild** is inserted as the node's first child.

        If **newChild** is the child of another node, it is reparented to this
        node. If **newChild** is a child of this node, then its position in the
        list of children is changed.

        If **newChild** is a **QDomDocumentFragment** , then the children of the
        fragment are removed from the fragment and inserted before **refChild**.

        Returns a new reference to **newChild** on success or a **null node**
        on failure.

        The DOM specification disallow inserting attribute nodes, but due to
        historical reasons QDom accept them nevertheless.

        **See also** **insertAfter** (), **replaceChild** (), **removeChild**
        (), and **appendChild** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtNetwork import *
import enum


class QNetworkInterface(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qnetworkinterface.html

    **Detailed Description**

    QNetworkInterface represents one network interface attached to the host
    where the program is being run. Each network interface may contain zero or
    more IP addresses, each of which is optionally associated with a netmask
    and/or a broadcast address. The list of such trios can be obtained with
    **addressEntries** (). Alternatively, when the netmask or the broadcast
    addresses or other information aren't necessary, use the **allAddresses** ()
    convenience function to obtain just the IP addresses of the active
    interfaces.

    QNetworkInterface also reports the interface's hardware address with
    **hardwareAddress** ().

    Not all operating systems support reporting all features. Only the IPv4
    addresses are guaranteed to be listed by this class in all platforms. In
    particular, IPv6 address listing is only supported on Windows, Linux, macOS
    and the BSDs.

    **See also** **QNetworkAddressEntry** .
    """

    class InterfaceType(enum.Enum):
        Unknown: QNetworkInterface = ...
        Loopback: QNetworkInterface = ...
        Virtual: QNetworkInterface = ...
        Ethernet: QNetworkInterface = ...
        Slip: QNetworkInterface = ...
        CanBus: QNetworkInterface = ...
        Ppp: QNetworkInterface = ...
        Fddi: QNetworkInterface = ...
        Wifi: QNetworkInterface = ...
        Ieee80211: QNetworkInterface = ...
        Phonet: QNetworkInterface = ...
        Ieee802154: QNetworkInterface = ...
        SixLoWPAN: QNetworkInterface = ...
        Ieee80216: QNetworkInterface = ...
        Ieee1394: QNetworkInterface = ...

    class InterfaceFlag(enum.Flag):
        IsUp: QNetworkInterface = ...
        IsRunning: QNetworkInterface = ...
        CanBroadcast: QNetworkInterface = ...
        IsLoopBack: QNetworkInterface = ...
        IsPointToPoint: QNetworkInterface = ...
        CanMulticast: QNetworkInterface = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkinterface.html#QNetworkInterface

        **QNetworkInterface::QNetworkInterface()**

        Constructs an empty network interface object.
        """
        ...

    @typing.overload
    def __init__(self, other: "QNetworkInterface") -> None:
        """
        https://doc.qt.io/qt-6/qnetworkinterface.html#QNetworkInterface-1

        **QNetworkInterface::QNetworkInterface(const QNetworkInterface & other
        )**

        Creates a copy of the QNetworkInterface object contained in **other**.
        """
        ...

    def maximumTransmissionUnit(self) -> int:
        """
        https://doc.qt.io/qt-6/qnetworkinterface.html#maximumTransmissionUnit

        **[since 5.11] int QNetworkInterface::maximumTransmissionUnit() const**

        Returns the maximum transmission unit on this interface, if known, or 0
        otherwise.

        The maximum transmission unit is the largest packet that may be sent on
        this interface without incurring link-level fragmentation. Applications
        may use this value to calculate the size of the payload that will fit an
        unfragmented UDP datagram. Remember to subtract the sizes of headers
        used in your communication over the interface, e.g. TCP (20 bytes) or
        UDP (12), IPv4 (20) or IPv6 (40, absent some form of header
        compression), when computing how big a payload you can transmit. Also
        note that the MTU along the full path (the Path MTU) to the destination
        may be smaller than the interface's MTU.

        This function was introduced in Qt 5.11.

        **See also** **QUdpSocket** .
        """
        ...

    def type(self) -> "QNetworkInterface.InterfaceType":
        """
        https://doc.qt.io/qt-6/qnetworkinterface.html#type

        **[since 5.11] QNetworkInterface::InterfaceType
        QNetworkInterface::type() const**

        Returns the type of this interface, if it could be determined. If it
        could not be determined, this function returns
        **QNetworkInterface::Unknown** .

        This function was introduced in Qt 5.11.

        **See also** **hardwareAddress** ().
        """
        ...

    @staticmethod
    def interfaceNameFromIndex(index: int) -> str:
        """
        https://doc.qt.io/qt-6/qnetworkinterface.html#interfaceNameFromIndex

        **[static, since 5.7] QString
        QNetworkInterface::interfaceNameFromIndex(int index )**

        Returns the name of the interface whose index is **index** or an empty
        string if there is no interface with that index. This function should
        produce the same result as the following code, but will probably execute
        faster.

        **QNetworkInterface** ::interfaceFromIndex(index).name()

        This function was introduced in Qt 5.7.

        **See also** **interfaceFromIndex** (), **interfaceIndexFromName** (),
        and **QNetworkDatagram::interfaceIndex** ().
        """
        ...

    @staticmethod
    def interfaceIndexFromName(name: str) -> int:
        """
        https://doc.qt.io/qt-6/qnetworkinterface.html#interfaceIndexFromName

        **[static, since 5.7] int
        QNetworkInterface::interfaceIndexFromName(const QString & name )**

        Returns the index of the interface whose name is **name** or 0 if there
        is no interface with that name. This function should produce the same
        result as the following code, but will probably execute faster.

        **QNetworkInterface** ::interfaceFromName(name).index()

        This function was introduced in Qt 5.7.

        **See also** **interfaceFromName** (), **interfaceNameFromIndex** (),
        and **QNetworkDatagram::interfaceIndex** ().
        """
        ...

    def swap(self, other: "QNetworkInterface") -> None:
        """
        https://doc.qt.io/qt-6/qnetworkinterface.html#swap

        **[since 5.0] void QNetworkInterface::swap(QNetworkInterface & other )**

        Swaps this network interface instance with **other**. This function is
        very fast and never fails.

        This function was introduced in Qt 5.0.
        """
        ...

    def humanReadableName(self) -> str:
        """
        https://doc.qt.io/qt-6/qnetworkinterface.html#humanReadableName

        **QString QNetworkInterface::humanReadableName() const**

        Returns the human-readable name of this network interface on Windows,
        such as "Local Area Connection", if the name could be determined. If it
        couldn't, this function returns the same as **name** (). The human-
        readable name is a name that the user can modify in the Windows Control
        Panel, so it may change during the execution of the program.

        On Unix, this function currently always returns the same as **name** (),
        since Unix systems don't store a configuration for human-readable names.
        """
        ...

    def index(self) -> int:
        """
        https://doc.qt.io/qt-6/qnetworkinterface.html#index

        **int QNetworkInterface::index() const**

        Returns the interface system index, if known. This is an integer
        assigned by the operating system to identify this interface and it
        generally doesn't change. It matches the scope ID field in IPv6
        addresses.

        If the index isn't known, this function returns 0.
        """
        ...

    @staticmethod
    def allAddresses() -> typing.List[QHostAddress]:
        """
        https://doc.qt.io/qt-6/qnetworkinterface.html#allAddresses

        **[static] QList<QHostAddress> QNetworkInterface::allAddresses()**

        This convenience function returns all IP addresses found on the host
        machine. It is equivalent to calling **addressEntries** () on all the
        objects returned by **allInterfaces** () that are in the
        **QNetworkInterface::IsUp**  state to obtain lists of
        **QNetworkAddressEntry**  objects then calling
        **QNetworkAddressEntry::ip** () on each of these.
        """
        ...

    @staticmethod
    def allInterfaces() -> typing.List["QNetworkInterface"]:
        """
        https://doc.qt.io/qt-6/qnetworkinterface.html#allInterfaces

        **[static] QList<QNetworkInterface> QNetworkInterface::allInterfaces()**

        Returns a listing of all the network interfaces found on the host
        machine. In case of failure it returns a list with zero elements.
        """
        ...

    @staticmethod
    def interfaceFromIndex(index: int) -> "QNetworkInterface":
        """
        https://doc.qt.io/qt-6/qnetworkinterface.html#interfaceFromIndex

        **[static] QNetworkInterface QNetworkInterface::interfaceFromIndex(int
        index )**

        Returns a **QNetworkInterface**  object for the interface whose internal
        ID is **index**. Network interfaces have a unique identifier called the
        "interface index" to distinguish it from other interfaces on the system.
        Often, this value is assigned progressively and interfaces being removed
        and then added again get a different value every time.

        This index is also found in the IPv6 address' scope ID field.
        """
        ...

    @staticmethod
    def interfaceFromName(name: str) -> "QNetworkInterface":
        """
        https://doc.qt.io/qt-6/qnetworkinterface.html#interfaceFromName

        **[static] QNetworkInterface QNetworkInterface::interfaceFromName(const
        QString & name )**

        Returns a **QNetworkInterface**  object for the interface named
        **name**. If no such interface exists, this function returns an invalid
        **QNetworkInterface**  object.

        The string **name** may be either an actual interface name (such as
        "eth0" or "en1") or an interface index in string form ("1", "2", etc.).

        **See also** **name** () and **isValid** ().
        """
        ...

    def addressEntries(self) -> typing.List[QNetworkAddressEntry]:
        """
        https://doc.qt.io/qt-6/qnetworkinterface.html#addressEntries

        **QList<QNetworkAddressEntry> QNetworkInterface::addressEntries()
        const**

        Returns the list of IP addresses that this interface possesses along
        with their associated netmasks and broadcast addresses.

        If the netmask or broadcast address or other information is not
        necessary, you can call the **allAddresses** () function to obtain just
        the IP addresses of the active interfaces.
        """
        ...

    def hardwareAddress(self) -> str:
        """
        https://doc.qt.io/qt-6/qnetworkinterface.html#hardwareAddress

        **QString QNetworkInterface::hardwareAddress() const**

        Returns the low-level hardware address for this interface. On Ethernet
        interfaces, this will be a MAC address in string representation,
        separated by colons.

        Other interface types may have other types of hardware addresses.
        Implementations should not depend on this function returning a valid MAC
        address.

        **See also** **type** ().
        """
        ...

    def flags(self) -> "QNetworkInterface.InterfaceFlag":
        """
        https://doc.qt.io/qt-6/qnetworkinterface.html#flags

        **QNetworkInterface::InterfaceFlags QNetworkInterface::flags() const**

        Returns the flags associated with this network interface.
        """
        ...

    def name(self) -> str:
        """
        https://doc.qt.io/qt-6/qnetworkinterface.html#name

        **QString QNetworkInterface::name() const**

        Returns the name of this network interface. On Unix systems, this is a
        string containing the type of the interface and optionally a sequence
        number, such as "eth0", "lo" or "pcn0". On Windows, it's an internal ID
        that cannot be changed by the user.
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qnetworkinterface.html#isValid

        **bool QNetworkInterface::isValid() const**

        Returns `true` if this **QNetworkInterface**  object contains valid
        information about a network interface.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QStackedWidget(QFrame):
    """
    https://doc.qt.io/qt-6/qstackedwidget.html

    **Detailed Description**

    QStackedWidget can be used to create a user interface similar to the one
    provided by **QTabWidget** . It is a convenience layout widget built on top
    of the **QStackedLayout**  class.

    Like **QStackedLayout** , QStackedWidget can be constructed and populated
    with a number of child widgets ("pages"):

    **QWidget**  *firstPageWidget = new **QWidget** ;
            **QWidget**
    *secondPageWidget = new **QWidget** ;
            **QWidget**  *thirdPageWidget
    = new **QWidget** ;

            **QStackedWidget**  *stackedWidget = new
    **QStackedWidget** ;
            stackedWidget->addWidget(firstPageWidget);
    stackedWidget->addWidget(secondPageWidget);
    stackedWidget->addWidget(thirdPageWidget);

            **QVBoxLayout**
    *layout = new **QVBoxLayout** ;
            layout->addWidget(stackedWidget);
    setLayout(layout);

    QStackedWidget provides no intrinsic means for the user to switch page. This
    is typically done through a **QComboBox**  or a **QListWidget**  that stores
    the titles of the QStackedWidget's pages. For example:

    **QComboBox**  *pageComboBox = new **QComboBox** ;
    pageComboBox->addItem(tr("Page 1"));
            pageComboBox->addItem(tr("Page
    2"));
            pageComboBox->addItem(tr("Page 3"));
    connect(pageComboBox, &**QComboBox** ::activated,
    stackedWidget, &**QStackedWidget** ::setCurrentIndex);

    When populating a stacked widget, the widgets are added to an internal list.
    The **indexOf** () function returns the index of a widget in that list. The
    widgets can either be added to the end of the list using the **addWidget**
    () function, or inserted at a given index using the **insertWidget** ()
    function. The **removeWidget** () function removes a widget from the stacked
    widget. The number of widgets contained in the stacked widget can be
    obtained using the **count** () function.

    The **widget** () function returns the widget at a given index position. The
    index of the widget that is shown on screen is given by **currentIndex** ()
    and can be changed using **setCurrentIndex** (). In a similar manner, the
    currently shown widget can be retrieved using the **currentWidget** ()
    function, and altered using the **setCurrentWidget** () function.

    Whenever the current widget in the stacked widget changes or a widget is
    removed from the stacked widget, the **currentChanged** () and
    **widgetRemoved** () signals are emitted respectively.

    **See also** **QStackedLayout**  and **QTabWidget** .
    """

    def __init__(self, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qstackedwidget.html#QStackedWidget

        **QStackedWidget::QStackedWidget(QWidget * parent = nullptr)**

        Constructs a QStackedWidget with the given **parent**.

        **See also** **addWidget** () and **insertWidget** ().
        """
        ...

    def event(self, e: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qstackedwidget.html#event

        **[override virtual protected] bool QStackedWidget::event(QEvent * e )**

        Reimplements: **QFrame::event** (QEvent *e).
        """
        ...

    def setCurrentWidget(self, w: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qstackedwidget.html#setCurrentWidget

        **[slot] void QStackedWidget::setCurrentWidget(QWidget * widget )**

        Sets the current widget to be the specified **widget**. The new current
        widget must already be contained in this stacked widget.

        **See also** **currentWidget** () and **setCurrentIndex** ().
        """
        ...

    def setCurrentIndex(self, index: int) -> None:
        """
        https://doc.qt.io/qt-6/qstackedwidget.html#currentIndex-prop

        **currentIndex : int**

        This property holds the index position of the widget that is visible

        The current index is -1 if there is no current widget.

        By default, this property contains a value of -1 because the stack is
        initially empty.

        **Access functions:**

        int **currentIndex** () const
        void **setCurrentIndex** (int **index**
        )

        **Notifier signal:**

        void ****currentChanged** ** (int **index** )

        **See also** **currentWidget** () and **indexOf** ().

        **Member Function Documentation**
        """
        ...

    def __len__(self) -> int:
        ...

    def count(self) -> int:
        """
        https://doc.qt.io/qt-6/qstackedwidget.html#count-prop

        **[read-only] count : const int**

        This property holds the number of widgets contained by this stacked
        widget

        By default, this property contains a value of 0.

        **Access functions:**

        int **count** () const

        **See also** **currentIndex** () and **widget** ().
        """
        ...

    def widget(self, a0: int) -> QWidget:
        """
        https://doc.qt.io/qt-6/qstackedwidget.html#widget

        **QWidget *QStackedWidget::widget(int index ) const**

        Returns the widget at the given **index** , or `nullptr` if there is no
        such widget.

        **See also** **currentWidget** () and **indexOf** ().
        """
        ...

    def indexOf(self, a0: QWidget) -> int:
        """
        https://doc.qt.io/qt-6/qstackedwidget.html#indexOf

        **int QStackedWidget::indexOf(const QWidget * widget ) const**

        Returns the index of the given **widget** , or -1 if the given
        **widget** is not a child of the **QStackedWidget** .

        **See also** **currentIndex** () and **widget** ().
        """
        ...

    def currentIndex(self) -> int:
        """
        https://doc.qt.io/qt-6/qstackedwidget.html#currentIndex-prop

        **currentIndex : int**

        This property holds the index position of the widget that is visible

        The current index is -1 if there is no current widget.

        By default, this property contains a value of -1 because the stack is
        initially empty.

        **Access functions:**

        int **currentIndex** () const
        void **setCurrentIndex** (int **index**
        )

        **Notifier signal:**

        void ****currentChanged** ** (int **index** )

        **See also** **currentWidget** () and **indexOf** ().

        **Member Function Documentation**
        """
        ...

    def currentWidget(self) -> QWidget:
        """
        https://doc.qt.io/qt-6/qstackedwidget.html#currentWidget

        **QWidget *QStackedWidget::currentWidget() const**

        Returns the current widget, or `nullptr` if there are no child widgets.

        **See also** **currentIndex** () and **setCurrentWidget** ().
        """
        ...

    def removeWidget(self, w: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qstackedwidget.html#removeWidget

        **void QStackedWidget::removeWidget(QWidget * widget )**

        Removes **widget** from the **QStackedWidget** . i.e., **widget** is
        **not** deleted but simply removed from the stacked layout, causing it
        to be hidden.

        **Note:** Parent object and parent widget of **widget** will remain the
        **QStackedWidget** . If the application wants to reuse the removed
        **widget** , then it is recommended to re-parent it.

        **See also** **addWidget** (), **insertWidget** (), and
        **currentWidget** ().
        """
        ...

    def insertWidget(self, index: int, w: QWidget) -> int:
        """
        https://doc.qt.io/qt-6/qstackedwidget.html#insertWidget

        **int QStackedWidget::insertWidget(int index , QWidget * widget )**

        Inserts the given **widget** at the given **index** in the
        **QStackedWidget** . Ownership of **widget** is passed on to the
        **QStackedWidget** . If **index** is out of range, the **widget** is
        appended (in which case it is the actual index of the **widget** that is
        returned).

        If the **QStackedWidget**  was empty before this function is called, the
        given **widget** becomes the current widget.

        Inserting a new widget at an index less than or equal to the current
        index will increment the current index, but keep the current widget.

        **See also** **addWidget** (), **removeWidget** (), and
        **setCurrentWidget** ().
        """
        ...

    def addWidget(self, w: QWidget) -> int:
        """
        https://doc.qt.io/qt-6/qstackedwidget.html#addWidget

        **int QStackedWidget::addWidget(QWidget * widget )**

        Appends the given **widget** to the **QStackedWidget**  and returns the
        index position. Ownership of **widget** is passed on to the
        **QStackedWidget** .

        If the **QStackedWidget**  is empty before this function is called,
        **widget** becomes the current widget.

        **See also** **insertWidget** (), **removeWidget** (), and
        **setCurrentWidget** ().
        """
        ...

    @property
    def currentChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qstackedwidget.html#currentChanged

        **[signal] void QStackedWidget::currentChanged(int index )**

        This signal is emitted whenever the current widget changes.

        The parameter holds the **index** of the new current widget, or -1 if
        there isn't a new one (for example, if there are no widgets in the
        **QStackedWidget** ).

        **Note:** Notifier signal for property **currentIndex** .

        **See also** **currentWidget** () and **setCurrentWidget** ().
        """
        ...

    @property
    def widgetRemoved(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qstackedwidget.html#widgetRemoved

        **[signal] void QStackedWidget::widgetRemoved(int index )**

        This signal is emitted whenever a widget is removed. The widget's
        **index** is passed as parameter.

        **See also** **removeWidget** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtNetwork import *


class QTcpServer(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qtcpserver.html

    **Detailed Description**

    This class makes it possible to accept incoming TCP connections. You can
    specify the port or have QTcpServer pick one automatically. You can listen
    on a specific address or on all the machine's addresses.

    Call **listen** () to have the server listen for incoming connections. The
    **newConnection** () signal is then emitted each time a client connects to
    the server.

    Call **nextPendingConnection** () to accept the pending connection as a
    connected **QTcpSocket** . The function returns a pointer to a
    **QTcpSocket**  in **QAbstractSocket::ConnectedState**  that you can use for
    communicating with the client.

    If an error occurs, **serverError** () returns the type of error, and
    **errorString** () can be called to get a human readable description of what
    happened.

    When listening for connections, the address and port on which the server is
    listening are available as **serverAddress** () and **serverPort** ().

    Calling **close** () makes QTcpServer stop listening for incoming
    connections.

    Although QTcpServer is mostly designed for use with an event loop, it's
    possible to use it without one. In that case, you must use
    **waitForNewConnection** (), which blocks until either a connection is
    available or a timeout expires.

    **See also** **QTcpSocket** , **Fortune Server Example** , **Threaded
    Fortune Server Example** , **Loopback Example** , and **Torrent Example** .
    """

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qtcpserver.html#QTcpServer

        **QTcpServer::QTcpServer(QObject * parent = nullptr)**

        Constructs a QTcpServer object.

        **parent** is passed to the **QObject**  constructor.

        **See also** **listen** () and **setSocketDescriptor** ().
        """
        ...

    def addPendingConnection(self, socket: QTcpSocket) -> None:
        """
        https://doc.qt.io/qt-6/qtcpserver.html#addPendingConnection

        **[protected] void QTcpServer::addPendingConnection(QTcpSocket * socket
        )**

        This function is called by **QTcpServer::incomingConnection** () to add
        the **socket** to the list of pending incoming connections.

        **Note:** Don't forget to call this member from reimplemented
        **incomingConnection** () if you do not want to break the Pending
        Connections mechanism.

        **See also** **incomingConnection** ().
        """
        ...

    def incomingConnection(self, handle: PyQt6.sip.voidptr) -> None:
        """
        https://doc.qt.io/qt-6/qtcpserver.html#incomingConnection

        **[virtual protected] void QTcpServer::incomingConnection(qintptr
        socketDescriptor )**

        This virtual function is called by **QTcpServer**  when a new connection
        is available. The **socketDescriptor** argument is the native socket
        descriptor for the accepted connection.

        The base implementation creates a **QTcpSocket** , sets the socket
        descriptor and then stores the **QTcpSocket**  in an internal list of
        pending connections. Finally **newConnection** () is emitted.

        Reimplement this function to alter the server's behavior when a
        connection is available.

        If this server is using **QNetworkProxy**  then the **socketDescriptor**
        may not be usable with native socket functions, and should only be used
        with **QTcpSocket::setSocketDescriptor** ().

        **Note:** If another socket is created in the reimplementation of this
        method, it needs to be added to the Pending Connections mechanism by
        calling **addPendingConnection** ().

        **Note:** If you want to handle an incoming connection as a new
        **QTcpSocket**  object in another thread you have to pass the
        **socketDescriptor**  to the other thread and create the **QTcpSocket**
        object there and use its **setSocketDescriptor** () method.

        **See also** **newConnection** (), **nextPendingConnection** (), and
        **addPendingConnection** ().
        """
        ...

    def resumeAccepting(self) -> None:
        """
        https://doc.qt.io/qt-6/qtcpserver.html#resumeAccepting

        **[since 5.0] void QTcpServer::resumeAccepting()**

        Resumes accepting new connections.

        This function was introduced in Qt 5.0.

        **See also** **pauseAccepting** ().
        """
        ...

    def pauseAccepting(self) -> None:
        """
        https://doc.qt.io/qt-6/qtcpserver.html#pauseAccepting

        **[since 5.0] void QTcpServer::pauseAccepting()**

        Pauses accepting new connections. Queued connections will remain in
        queue.

        This function was introduced in Qt 5.0.

        **See also** **resumeAccepting** ().
        """
        ...

    def proxy(self) -> QNetworkProxy:
        """
        https://doc.qt.io/qt-6/qtcpserver.html#proxy

        **QNetworkProxy QTcpServer::proxy() const**

        Returns the network proxy for this socket. By default
        **QNetworkProxy::DefaultProxy**  is used.

        **See also** **setProxy** () and **QNetworkProxy** .
        """
        ...

    def setProxy(self, networkProxy: QNetworkProxy) -> None:
        """
        https://doc.qt.io/qt-6/qtcpserver.html#setProxy

        **void QTcpServer::setProxy(const QNetworkProxy & networkProxy )**

        Sets the explicit network proxy for this socket to **networkProxy**.

        To disable the use of a proxy for this socket, use the
        **QNetworkProxy::NoProxy**  proxy type:

        server->setProxy(**QNetworkProxy** ::NoProxy);

        **See also** **proxy** () and **QNetworkProxy** .
        """
        ...

    def errorString(self) -> str:
        """
        https://doc.qt.io/qt-6/qtcpserver.html#errorString

        **QString QTcpServer::errorString() const**

        Returns a human readable description of the last error that occurred.

        **See also** **serverError** ().
        """
        ...

    def serverError(self) -> QAbstractSocket.SocketError:
        """
        https://doc.qt.io/qt-6/qtcpserver.html#serverError

        **QAbstractSocket::SocketError QTcpServer::serverError() const**

        Returns an error code for the last error that occurred.

        **See also** **errorString** ().
        """
        ...

    def nextPendingConnection(self) -> QTcpSocket:
        """
        https://doc.qt.io/qt-6/qtcpserver.html#nextPendingConnection

        **[virtual] QTcpSocket *QTcpServer::nextPendingConnection()**

        Returns the next pending connection as a connected **QTcpSocket**
        object.

        The socket is created as a child of the server, which means that it is
        automatically deleted when the **QTcpServer**  object is destroyed. It
        is still a good idea to delete the object explicitly when you are done
        with it, to avoid wasting memory.

        `nullptr` is returned if this function is called when there are no
        pending connections.

        **Note:** The returned **QTcpSocket**  object cannot be used from
        another thread. If you want to use an incoming connection from another
        thread, you need to override **incomingConnection** ().

        **See also** **hasPendingConnections** ().
        """
        ...

    def hasPendingConnections(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtcpserver.html#hasPendingConnections

        **[virtual] bool QTcpServer::hasPendingConnections() const**

        Returns `true` if the server has a pending connection; otherwise returns
        `false`.

        **See also** **nextPendingConnection** () and
        **setMaxPendingConnections** ().
        """
        ...

    def waitForNewConnection(self, msecs: int = ...) -> typing.Tuple[bool, bool]:
        """
        https://doc.qt.io/qt-6/qtcpserver.html#waitForNewConnection

        **bool QTcpServer::waitForNewConnection(int msec = 0, bool * timedOut =
        nullptr)**

        Waits for at most **msec** milliseconds or until an incoming connection
        is available. Returns `true` if a connection is available; otherwise
        returns `false`. If the operation timed out and **timedOut** is not
        `nullptr`, * **timedOut** will be set to true.

        This is a blocking function call. Its use is disadvised in a single-
        threaded GUI application, since the whole application will stop
        responding until the function returns. waitForNewConnection() is mostly
        useful when there is no event loop available.

        The non-blocking alternative is to connect to the **newConnection** ()
        signal.

        If msec is -1, this function will not time out.

        **See also** **hasPendingConnections** () and **nextPendingConnection**
        ().
        """
        ...

    def setSocketDescriptor(self, socketDescriptor: PyQt6.sip.voidptr) -> bool:
        """
        https://doc.qt.io/qt-6/qtcpserver.html#setSocketDescriptor

        **bool QTcpServer::setSocketDescriptor(qintptr socketDescriptor )**

        Sets the socket descriptor this server should use when listening for
        incoming connections to **socketDescriptor**. Returns `true` if the
        socket is set successfully; otherwise returns `false`.

        The socket is assumed to be in listening state.

        **See also** **socketDescriptor** () and **isListening** ().
        """
        ...

    def socketDescriptor(self) -> PyQt6.sip.voidptr:
        """
        https://doc.qt.io/qt-6/qtcpserver.html#socketDescriptor

        **qintptr QTcpServer::socketDescriptor() const**

        Returns the native socket descriptor the server uses to listen for
        incoming instructions, or -1 if the server is not listening.

        If the server is using **QNetworkProxy** , the returned descriptor may
        not be usable with native socket functions.

        **See also** **setSocketDescriptor** () and **isListening** ().
        """
        ...

    def serverAddress(self) -> QHostAddress:
        """
        https://doc.qt.io/qt-6/qtcpserver.html#serverAddress

        **QHostAddress QTcpServer::serverAddress() const**

        Returns the server's address if the server is listening for connections;
        otherwise returns **QHostAddress::Null** .

        **See also** **serverPort** () and **listen** ().
        """
        ...

    def serverPort(self) -> int:
        """
        https://doc.qt.io/qt-6/qtcpserver.html#serverPort

        **quint16 QTcpServer::serverPort() const**

        Returns the server's port if the server is listening for connections;
        otherwise returns 0.

        **See also** **serverAddress** () and **listen** ().
        """
        ...

    def maxPendingConnections(self) -> int:
        """
        https://doc.qt.io/qt-6/qtcpserver.html#maxPendingConnections

        **int QTcpServer::maxPendingConnections() const**

        Returns the maximum number of pending accepted connections. The default
        is 30.

        **See also** **setMaxPendingConnections** () and
        **hasPendingConnections** ().
        """
        ...

    def setMaxPendingConnections(self, numConnections: int) -> None:
        """
        https://doc.qt.io/qt-6/qtcpserver.html#setMaxPendingConnections

        **void QTcpServer::setMaxPendingConnections(int numConnections )**

        Sets the maximum number of pending accepted connections to
        **numConnections**. **QTcpServer**  will accept no more than
        **numConnections** incoming connections before **nextPendingConnection**
        () is called. By default, the limit is 30 pending connections.

        Clients may still able to connect after the server has reached its
        maximum number of pending connections (i.e., **QTcpSocket**  can still
        emit the connected() signal). **QTcpServer**  will stop accepting the
        new connections, but the operating system may still keep them in queue.

        **See also** **maxPendingConnections** () and **hasPendingConnections**
        ().
        """
        ...

    def isListening(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtcpserver.html#isListening

        **bool QTcpServer::isListening() const**

        Returns `true` if the server is currently listening for incoming
        connections; otherwise returns `false`.

        **See also** **listen** ().
        """
        ...

    def close(self) -> None:
        """
        https://doc.qt.io/qt-6/qtcpserver.html#close

        **void QTcpServer::close()**

        Closes the server. The server will no longer listen for incoming
        connections.

        **See also** **listen** ().
        """
        ...

    def listen(
        self,
        address: typing.Union[QHostAddress, QHostAddress.SpecialAddress] = ...,
        port: int = ...,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qtcpserver.html#listen

        **bool QTcpServer::listen(const QHostAddress & address =
        QHostAddress::Any, quint16 port = 0)**

        Tells the server to listen for incoming connections on address
        **address** and port **port**. If **port** is 0, a port is chosen
        automatically. If **address** is **QHostAddress::Any** , the server will
        listen on all network interfaces.

        Returns `true` on success; otherwise returns `false`.

        **See also** **isListening** ().
        """
        ...

    @property
    def acceptError(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtcpserver.html#acceptError

        **[signal, since 5.0] void
        QTcpServer::acceptError(QAbstractSocket::SocketError socketError )**

        This signal is emitted when accepting a new connection results in an
        error. The **socketError** parameter describes the type of error that
        occurred.

        This function was introduced in Qt 5.0.

        **See also** **pauseAccepting** () and **resumeAccepting** ().
        """
        ...

    @property
    def newConnection(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtcpserver.html#newConnection

        **[signal] void QTcpServer::newConnection()**

        This signal is emitted every time a new connection is available.

        **See also** **hasPendingConnections** () and **nextPendingConnection**
        ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QSessionManager(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qsessionmanager.html

    **Detailed Description**

    A session manager in a desktop environment (in which Qt GUI applications
    live) keeps track of a session, which is a group of running applications,
    each of which has a particular state. The state of an application contains
    (most notably) the documents the application has open and the position and
    size of its windows.

    The session manager is used to save the session, e.g., when the machine is
    shut down, and to restore a session, e.g., when the machine is started up.
    We recommend that you use **QSettings**  to save an application's settings,
    for example, window positions, recently used files, etc. When the
    application is restarted by the session manager, you can restore the
    settings.

    QSessionManager provides an interface between the application and the
    platform's session manager. In Qt, session management requests for action
    are handled by the two signals **QGuiApplication::commitDataRequest** () and
    **QGuiApplication::saveStateRequest** (). Both provide a reference to a
    QSessionManager object as argument. The session manager can only be accessed
    in slots invoked by these signals.

    No user interaction is possible **unless** the application gets explicit
    permission from the session manager. You ask for permission by calling
    **allowsInteraction** () or, if it is really urgent,
    **allowsErrorInteraction** (). Qt does not enforce this, but the session
    manager may.

    You can try to abort the shutdown process by calling **cancel** ().

    For sophisticated session managers provided on Unix/X11, QSessionManager
    offers further possibilities to fine-tune an application's session
    management behavior: **setRestartCommand** (), **setDiscardCommand** (),
    **setRestartHint** (), **setProperty** (), **requestPhase2** (). See the
    respective function descriptions for further details.

    **See also** **QGuiApplication**  and **Session Management** .
    """

    class RestartHint(enum.Enum):
        RestartIfRunning: QSessionManager = ...
        RestartAnyway: QSessionManager = ...
        RestartImmediately: QSessionManager = ...
        RestartNever: QSessionManager = ...

    def requestPhase2(self) -> None:
        """
        https://doc.qt.io/qt-6/qsessionmanager.html#requestPhase2

        **void QSessionManager::requestPhase2()**

        Requests a second session management phase for the application. The
        application may then return immediately from the
        **QGuiApplication::commitDataRequest** () or
        **QApplication::saveStateRequest** () function, and they will be called
        again once most or all other applications have finished their session
        management.

        The two phases are useful for applications such as the X11 window
        manager that need to store information about another application's
        windows and therefore have to wait until these applications have
        completed their respective session management tasks.

        **Note:** If another application has requested a second phase it may get
        called before, simultaneously with, or after your application's second
        phase.

        **See also** **isPhase2** ().
        """
        ...

    def isPhase2(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsessionmanager.html#isPhase2

        **bool QSessionManager::isPhase2() const**

        Returns `true` if the session manager is currently performing a second
        session management phase; otherwise returns `false`.

        **See also** **requestPhase2** ().
        """
        ...

    @typing.overload
    def setManagerProperty(self, name: str, value: str) -> None:
        """
        https://doc.qt.io/qt-6/qsessionmanager.html#setManagerProperty

        **void QSessionManager::setManagerProperty(const QString & name , const
        QStringList & value )**

        Low-level write access to the application's identification and state
        record are kept in the session manager.

        The property called **name** has its value set to the string list
        **value**.
        """
        ...

    @typing.overload
    def setManagerProperty(self, name: str, value: typing.Iterable[str]) -> None:
        """
        https://doc.qt.io/qt-6/qsessionmanager.html#setManagerProperty-1

        **void QSessionManager::setManagerProperty(const QString & name , const
        QString & value )**

        This is an overloaded function.

        Low-level write access to the application's identification and state
        records are kept in the session manager.

        The property called **name** has its value set to the string **value**.
        """
        ...

    def discardCommand(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qsessionmanager.html#discardCommand

        **QStringList QSessionManager::discardCommand() const**

        Returns the currently set discard command.

        To iterate over the list, you can use the **foreach**  pseudo-keyword:

        const **QStringList**  commands = mySession.discardCommand();
            for
        (const **QString**  &command : mySession.discardCommand())
        do_something(command);

        **See also** **setDiscardCommand** (), **restartCommand** (), and
        **setRestartCommand** ().
        """
        ...

    def setDiscardCommand(self, a0: typing.Iterable[str]) -> None:
        """
        https://doc.qt.io/qt-6/qsessionmanager.html#setDiscardCommand

        **void QSessionManager::setDiscardCommand(const QStringList & command
        )**

        Sets the discard command to the given **command**.

        **See also** **discardCommand** () and **setRestartCommand** ().
        """
        ...

    def restartCommand(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qsessionmanager.html#restartCommand

        **QStringList QSessionManager::restartCommand() const**

        Returns the currently set restart command.

        To iterate over the list, you can use the **foreach**  pseudo-keyword:

        const **QStringList**  commands = mySession.restartCommand();
            for
        (const **QString**  &command : commands)
                do_something(command);

        **See also** **setRestartCommand** () and **restartHint** ().
        """
        ...

    def setRestartCommand(self, a0: typing.Iterable[str]) -> None:
        """
        https://doc.qt.io/qt-6/qsessionmanager.html#setRestartCommand

        **void QSessionManager::setRestartCommand(const QStringList & command
        )**

        If the session manager is capable of restoring sessions it will execute
        **command** in order to restore the application. The command defaults to

        appname -session id

        The `-session` option is mandatory; otherwise **QGuiApplication**
        cannot tell whether it has been restored or what the current session
        identifier is. See **QGuiApplication::isSessionRestored** () and
        **QGuiApplication::sessionId** () for details.

        If your application is very simple, it may be possible to store the
        entire application state in additional command line options. This is
        usually a very bad idea because command lines are often limited to a few
        hundred bytes. Instead, use **QSettings** , temporary files, or a
        database for this purpose. By marking the data with the unique
        **sessionId** (), you will be able to restore the application in a
        future session.

        **See also** **restartCommand** (), **setDiscardCommand** (), and
        **setRestartHint** ().
        """
        ...

    def restartHint(self) -> "QSessionManager.RestartHint":
        """
        https://doc.qt.io/qt-6/qsessionmanager.html#restartHint

        **QSessionManager::RestartHint QSessionManager::restartHint() const**

        Returns the application's current restart hint. The default is
        `RestartIfRunning`.

        **See also** **setRestartHint** ().
        """
        ...

    def setRestartHint(self, a0: "QSessionManager.RestartHint") -> None:
        """
        https://doc.qt.io/qt-6/qsessionmanager.html#setRestartHint

        **void QSessionManager::setRestartHint(QSessionManager::RestartHint hint
        )**

        Sets the application's restart hint to **hint**. On application startup,
        the hint is set to `RestartIfRunning`.

        **Note:** These flags are only hints, a session manager may or may not
        respect them.

        We recommend setting the restart hint in
        **QGuiApplication::saveStateRequest** () because most session managers
        perform a checkpoint shortly after an application's startup.

        **See also** **restartHint** ().
        """
        ...

    def cancel(self) -> None:
        """
        https://doc.qt.io/qt-6/qsessionmanager.html#cancel

        **void QSessionManager::cancel()**

        Tells the session manager to cancel the shutdown process. Applications
        should not call this function without asking the user first.

        **See also** **allowsInteraction** () and **allowsErrorInteraction** ().
        """
        ...

    def release(self) -> None:
        """
        https://doc.qt.io/qt-6/qsessionmanager.html#release

        **void QSessionManager::release()**

        Releases the session manager's interaction semaphore after an
        interaction phase.

        **See also** **allowsInteraction** () and **allowsErrorInteraction** ().
        """
        ...

    def allowsErrorInteraction(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsessionmanager.html#allowsErrorInteraction

        **bool QSessionManager::allowsErrorInteraction()**

        Returns `true` if error interaction is permitted; otherwise returns
        `false`.

        This is similar to **allowsInteraction** (), but also enables the
        application to tell the user about any errors that occur. Session
        managers may give error interaction requests higher priority, which
        means that it is more likely that an error interaction is permitted.
        However, you are still not guaranteed that the session manager will
        allow interaction.

        **See also** **allowsInteraction** (), **release** (), and **cancel**
        ().
        """
        ...

    def allowsInteraction(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsessionmanager.html#allowsInteraction

        **bool QSessionManager::allowsInteraction()**

        Asks the session manager for permission to interact with the user.
        Returns true if interaction is permitted; otherwise returns `false`.

        The rationale behind this mechanism is to make it possible to
        synchronize user interaction during a shutdown. Advanced session
        managers may ask all applications simultaneously to commit their data,
        resulting in a much faster shutdown.

        When the interaction is completed we strongly recommend releasing the
        user interaction semaphore with a call to **release** (). This way,
        other applications may get the chance to interact with the user while
        your application is still busy saving data. (The semaphore is implicitly
        released when the application exits.)

        If the user decides to cancel the shutdown process during the
        interaction phase, you must tell the session manager that this has
        happened by calling **cancel** ().

        Here's an example of how an application's
        **QGuiApplication::commitDataRequest** () might be implemented:

        MyMainWidget::MyMainWidget(**QWidget**  *parent)
                : **QWidget**
        (parent)
            {
                connect(**qApp** , &**QGuiApplication**
        ::commitDataRequest,
                        this, &MyMainWidget::commitData);
        }

            void MyMainWidget::commitData(QSessionManager& manager)
            {
        if (manager.allowsInteraction()) {
                    int ret = **QMessageBox**
        ::warning(
                                mainWindow,
        tr("My Application"),
                                tr("Save changes to
        document?"),
                                **QMessageBox** ::Save |
        **QMessageBox** ::Discard | **QMessageBox** ::Cancel);
        switch (ret) {
                    case **QMessageBox** ::Save:
        manager.release();
                        if (!saveDocument())
        manager.cancel();
                        break;
                    case
        **QMessageBox** ::Discard:
                        break;
                    case
        **QMessageBox** ::Cancel:
                    default:
        manager.cancel();
                    }
                } else {
                    // we did
        not get permission to interact, then
                    // do something
        reasonable instead
                }
            }

        If an error occurred within the application while saving its data, you
        may want to try **allowsErrorInteraction** () instead.

        **See also** **QGuiApplication::commitDataRequest** (), **release** (),
        and **cancel** ().
        """
        ...

    def sessionKey(self) -> str:
        """
        https://doc.qt.io/qt-6/qsessionmanager.html#sessionKey

        **QString QSessionManager::sessionKey() const**

        Returns the session key in the current session.

        If the application has been restored from an earlier session, this key
        is the same as it was when the previous session ended.

        The session key changes with every call of commitData() or saveState().

        **See also** **sessionId** () and **QGuiApplication::sessionKey** ().
        """
        ...

    def sessionId(self) -> str:
        """
        https://doc.qt.io/qt-6/qsessionmanager.html#sessionId

        **QString QSessionManager::sessionId() const**

        Returns the identifier of the current session.

        If the application has been restored from an earlier session, this
        identifier is the same as it was in the earlier session.

        **See also** **sessionKey** () and **QGuiApplication::sessionId** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import PyQt6.sip


class QRecursiveMutex(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qrecursivemutex.html

    **Detailed Description**

    The QRecursiveMutex class is a mutex, like **QMutex** , with which it is
    API-compatible. It differs from **QMutex**  by accepting **lock** () calls
    from the same thread any number of times. **QMutex**  would deadlock in this
    situation.

    QRecursiveMutex is much more expensive to construct and operate on, so use a
    plain **QMutex**  whenever you can. Sometimes, one public function, however,
    calls another public function, and they both need to lock the same mutex. In
    this case, you have two options:

    * Factor the code that needs mutex protection into private functions, which
    assume that the mutex is held when they are called, and lock a plain
    **QMutex**  in the public functions before you call the private
    implementation ones.
      * Or use a recursive mutex, so it doesn't matter that
    the first public function has already locked the mutex when the second one
    wishes to do so.

    **See also** **QMutex** , **QMutexLocker** , **QReadWriteLock** ,
    **QSemaphore** , and **QWaitCondition** .
    """

    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qrecursivemutex.html#QRecursiveMutex-2

        **QRecursiveMutex::QRecursiveMutex()**

        Constructs a new recursive mutex. The mutex is created in an unlocked
        state.

        **See also** **lock** () and **unlock** ().
        """
        ...

    def unlock(self) -> None:
        """
        https://doc.qt.io/qt-6/qrecursivemutex.html#unlock

        **void QRecursiveMutex::unlock()**

        Unlocks the mutex. Attempting to unlock a mutex in a different thread to
        the one that locked it results in an error. Unlocking a mutex that is
        not locked results in undefined behavior.

        **See also** **lock** ().
        """
        ...

    def tryLock(self, timeout: int = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qrecursivemutex.html#tryLock

        **bool QRecursiveMutex::tryLock(int timeout = 0)**

        Attempts to lock the mutex. This function returns `true` if the lock was
        obtained; otherwise it returns `false`. If another thread has locked the
        mutex, this function will wait for at most **timeout** milliseconds for
        the mutex to become available.

        Note: Passing a negative number as the **timeout** is equivalent to
        calling **lock** (), i.e. this function will wait forever until mutex
        can be locked if **timeout** is negative.

        If the lock was obtained, the mutex must be unlocked with **unlock** ()
        before another thread can successfully lock it.

        Calling this function multiple times on the same mutex from the same
        thread is allowed.

        **See also** **lock** () and **unlock** ().
        """
        ...

    def lock(self) -> None:
        """
        https://doc.qt.io/qt-6/qrecursivemutex.html#lock

        **void QRecursiveMutex::lock()**

        Locks the mutex. If another thread has locked the mutex then this call
        will block until that thread has unlocked it.

        Calling this function multiple times on the same mutex from the same
        thread is allowed.

        **See also** **unlock** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtWidgets
from PyQt6 import QtQuick
from PyQt6 import QtQml
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtQuickWidgets import *
import enum


class QQuickWidget(QtWidgets.QWidget):
    """
    https://doc.qt.io/qt-6/qquickwidget.html

    **Detailed Description**

    This is a convenience wrapper for **QQuickWindow**  which will automatically
    load and display a QML scene when given the URL of the main source file.
    Alternatively, you can instantiate your own objects using **QQmlComponent**
    and place them in a manually set up QQuickWidget.

    Typical usage:

    **QQuickWidget**  *view = new **QQuickWidget** ;
    view->setSource(**QUrl** ::fromLocalFile("myqmlfile.qml"));
    view->show();

    To receive errors related to loading and executing QML with QQuickWidget,
    you can connect to the **statusChanged** () signal and monitor for
    **QQuickWidget::Error** . The errors are available via
    **QQuickWidget::errors** ().

    QQuickWidget also manages sizing of the view and root object. By default,
    the **resizeMode**  is **SizeViewToRootObject** , which will load the
    component and resize it to the size of the view. Alternatively the
    **resizeMode**  may be set to **SizeRootObjectToView**  which will resize
    the view to the size of the root object.

    **Note:** QQuickWidget is an alternative to using **QQuickView**  and
    **QWidget::createWindowContainer** (). The restrictions on stacking order do
    not apply, making QQuickWidget the more flexible alternative, behaving more
    like an ordinary widget.

    **Note:** However, the above mentioned advantages come at the expense of
    performance. Unlike **QQuickWindow**  and **QQuickView** , QQuickWidget
    requires rendering into OpenGL framebuffer objects, which needs to be
    enforced by calling **QQuickWindow::setGraphicsApi**
    (**QSGRendererInterface::OpenGLRhi** ) at startup. This will naturally carry
    a minor performance hit.

    **Note:** Using QQuickWidget disables the threaded render loop on all
    platforms. This means that some of the benefits of threaded rendering, for
    example **Animator**  classes and vsync driven animations, will not be
    available.

    **Note:** Avoid calling **winId** () on a QQuickWidget. This function
    triggers the creation of a native window, resulting in reduced performance
    and possibly rendering glitches. The entire purpose of QQuickWidget is to
    render Quick scenes without a separate native window, hence making it a
    native widget should always be avoided.

    **Scene Graph and Context Persistency**

    QQuickWidget honors **QQuickWindow::isPersistentSceneGraph** (), meaning
    that applications can decide - by calling
    **QQuickWindow::setPersistentSceneGraph** () on the window returned from the
    **quickWindow** () function - to let scenegraph nodes and other Qt Quick
    scene related resources be released whenever the widget becomes hidden. By
    default persistency is enabled, just like with **QQuickWindow** .

    When running with the OpenGL backend of the scene graph, **QQuickWindow**
    offers the possibility to disable persistent OpenGL contexts as well. This
    setting is currently ignored by QQuickWidget and the context is always
    persistent. The OpenGL context is thus not destroyed when hiding the widget.
    The context is destroyed only when the widget is destroyed or when the
    widget gets reparented into another top-level widget's child hierarchy.
    However, some applications, in particular those that have their own graphics
    resources due to performing custom OpenGL rendering in the Qt Quick scene,
    may wish to disable the latter since they may not be prepared to handle the
    loss of the context when moving a QQuickWidget into another window. Such
    applications can set the QCoreApplication::AA_ShareOpenGLContexts attribute.
    For a discussion on the details of resource initialization and cleanup,
    refer to the QOpenGLWidget documentation.

    **Note:** QQuickWidget offers less fine-grained control over its internal
    OpenGL context than QOpenGLWidget, and there are subtle differences, most
    notably that disabling the persistent scene graph will lead to destroying
    the context on a window change regardless of the presence of
    QCoreApplication::AA_ShareOpenGLContexts.

    **Limitations**

    Putting other widgets underneath and making the QQuickWidget transparent
    will not lead to the expected results: the widgets underneath will not be
    visible. This is because in practice the QQuickWidget is drawn before all
    other regular, non-OpenGL widgets, and so see-through types of solutions are
    not feasible. Other type of layouts, like having widgets on top of the
    QQuickWidget, will function as expected.

    When absolutely necessary, this limitation can be overcome by setting the
    **Qt::WA_AlwaysStackOnTop**  attribute on the QQuickWidget. Be aware,
    however that this breaks stacking order. For example it will not be possible
    to have other widgets on top of the QQuickWidget, so it should only be used
    in situations where a semi-transparent QQuickWidget with other widgets
    visible underneath is required.

    This limitation only applies when there are other widgets underneath the
    QQuickWidget inside the same window. Making the window semi-transparent,
    with other applications and the desktop visible in the background, is done
    in the traditional way: Set **Qt::WA_TranslucentBackground**  on the top-
    level window, request an alpha channel, and change the Qt Quick Scenegraph's
    clear color to **Qt::transparent**  via **setClearColor** ().

    **Support when not using OpenGL**

    In addition to OpenGL, the `software` backend of Qt Quick also supports
    QQuickWidget. Other backends, for example OpenVG, are not compatible however
    and attempting to construct a QQuickWidget will lead to problems.

    **Tab Key Handling**

    On press of the `[TAB]` key, the item inside the QQuickWidget gets focus. If
    this item can handle `[TAB]` key press, focus will change accordingly within
    the item, otherwise the next widget in the focus chain gets focus.

    **See also** **Exposing Attributes of C++ Types to QML** , **Qt Quick
    Widgets Example** , and **QQuickView** .
    """

    class Status(enum.Enum):
        Null: QQuickWidget = ...
        Ready: QQuickWidget = ...
        Loading: QQuickWidget = ...
        Error: QQuickWidget = ...

    class ResizeMode(enum.Enum):
        SizeViewToRootObject: QQuickWidget = ...
        SizeRootObjectToView: QQuickWidget = ...

    @typing.overload
    def __init__(self, parent: typing.Optional[QtWidgets.QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qquickwidget.html#QQuickWidget

        **QQuickWidget::QQuickWidget(QWidget * parent = nullptr)**

        Constructs a QQuickWidget with the given **parent**. The default value
        of **parent** is 0.
        """
        ...

    @typing.overload
    def __init__(self, engine: QtQml.QQmlEngine, parent: QtWidgets.QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qquickwidget.html#QQuickWidget-1

        **QQuickWidget::QQuickWidget(QQmlEngine * engine , QWidget * parent )**

        Constructs a QQuickWidget with the given QML **engine** and **parent**.

        Note: In this case, the QQuickWidget does not own the given **engine**
        object; it is the caller's responsibility to destroy the engine. If the
        **engine** is deleted before the view, **status** () will return
        **QQuickWidget::Error** .

        **See also** **Status** , **status** (), and **errors** ().
        """
        ...

    @typing.overload
    def __init__(
        self, source: QtCore.QUrl, parent: typing.Optional[QtWidgets.QWidget] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qquickwidget.html#QQuickWidget-2

        **QQuickWidget::QQuickWidget(const QUrl & source , QWidget * parent =
        nullptr)**

        Constructs a QQuickWidget with the given QML **source** and **parent**.
        The default value of **parent** is 0.
        """
        ...

    def focusNextPrevChild(self, next: bool) -> bool:
        """
        https://doc.qt.io/qt-6/qquickwidget.html#focusNextPrevChild

        **[override virtual protected] bool
        QQuickWidget::focusNextPrevChild(bool next )**

        Reimplements: **QWidget::focusNextPrevChild** (bool next).
        """
        ...

    def quickWindow(self) -> QtQuick.QQuickWindow:
        """
        https://doc.qt.io/qt-6/qquickwidget.html#quickWindow

        **[since 5.5] QQuickWindow *QQuickWidget::quickWindow() const**

        Returns the offscreen **QQuickWindow**  which is used by this widget to
        drive the Qt Quick rendering. This is useful if you want to use
        **QQuickWindow**  APIs that are not currently exposed by
        **QQuickWidget** , for instance connecting to the
        **QQuickWindow::beforeRendering** () signal in order to draw native
        OpenGL content below Qt Quick's own rendering.

        **Warning:** Use the return value of this function with caution. In
        particular, do not ever attempt to show the **QQuickWindow** , and be
        very careful when using other **QWindow** -only APIs.

        **Warning:** The offscreen window may be deleted (and recreated) during
        the life time of the **QQuickWidget** , particularly when the widget is
        moved to another **QQuickWindow** . If you need to know when the window
        has been replaced, connect to its **destroyed** () signal.

        This function was introduced in Qt 5.5.
        """
        ...

    def setClearColor(
        self, color: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor, int]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qquickwidget.html#setClearColor

        **void QQuickWidget::setClearColor(const QColor & color )**

        Sets the clear **color**. By default this is an opaque color.

        To get a semi-transparent **QQuickWidget** , call this function with
        **color** set to **Qt::transparent** , set the
        **Qt::WA_TranslucentBackground**  widget attribute on the top-level
        window, and request an alpha channel via **setFormat** ().

        **See also** **QQuickWindow::setColor** ().
        """
        ...

    def grabFramebuffer(self) -> QtGui.QImage:
        """
        https://doc.qt.io/qt-6/qquickwidget.html#grabFramebuffer

        **QImage QQuickWidget::grabFramebuffer() const**

        Renders a frame and reads it back into an image.

        **Note:** This is a potentially expensive operation.
        """
        ...

    def paintEvent(self, event: QtGui.QPaintEvent) -> None:
        """
        https://doc.qt.io/qt-6/qquickwidget.html#paintEvent

        **[override virtual protected] void QQuickWidget::paintEvent(QPaintEvent
        * event )**

        Reimplements: **QWidget::paintEvent** (QPaintEvent *event).
        """
        ...

    def dropEvent(self, a0: QtGui.QDropEvent) -> None:
        """
        https://doc.qt.io/qt-6/qquickwidget.html#dropEvent

        **[override virtual protected] void QQuickWidget::dropEvent(QDropEvent *
        e )**

        Reimplements: **QWidget::dropEvent** (QDropEvent *event).
        """
        ...

    def dragLeaveEvent(self, a0: QtGui.QDragLeaveEvent) -> None:
        """
        https://doc.qt.io/qt-6/qquickwidget.html#dragLeaveEvent

        **[override virtual protected] void
        QQuickWidget::dragLeaveEvent(QDragLeaveEvent * e )**

        Reimplements: **QWidget::dragLeaveEvent** (QDragLeaveEvent *event).
        """
        ...

    def dragMoveEvent(self, a0: QtGui.QDragMoveEvent) -> None:
        """
        https://doc.qt.io/qt-6/qquickwidget.html#dragMoveEvent

        **[override virtual protected] void
        QQuickWidget::dragMoveEvent(QDragMoveEvent * e )**

        Reimplements: **QWidget::dragMoveEvent** (QDragMoveEvent *event).
        """
        ...

    def dragEnterEvent(self, a0: QtGui.QDragEnterEvent) -> None:
        """
        https://doc.qt.io/qt-6/qquickwidget.html#dragEnterEvent

        **[override virtual protected] void
        QQuickWidget::dragEnterEvent(QDragEnterEvent * e )**

        Reimplements: **QWidget::dragEnterEvent** (QDragEnterEvent *event).
        """
        ...

    def focusOutEvent(self, event: QtGui.QFocusEvent) -> None:
        """
        https://doc.qt.io/qt-6/qquickwidget.html#focusOutEvent

        **[override virtual protected] void
        QQuickWidget::focusOutEvent(QFocusEvent * event )**

        Reimplements: **QWidget::focusOutEvent** (QFocusEvent *event).
        """
        ...

    def focusInEvent(self, event: QtGui.QFocusEvent) -> None:
        """
        https://doc.qt.io/qt-6/qquickwidget.html#focusInEvent

        **[override virtual protected] void
        QQuickWidget::focusInEvent(QFocusEvent * event )**

        Reimplements: **QWidget::focusInEvent** (QFocusEvent *event).
        """
        ...

    def event(self, a0: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qquickwidget.html#event

        **[override virtual protected] bool QQuickWidget::event(QEvent * e )**

        Reimplements: **QWidget::event** (QEvent *event).
        """
        ...

    def wheelEvent(self, a0: QtGui.QWheelEvent) -> None:
        """
        https://doc.qt.io/qt-6/qquickwidget.html#wheelEvent

        **[override virtual protected] void QQuickWidget::wheelEvent(QWheelEvent
        * e )**

        Reimplements: **QWidget::wheelEvent** (QWheelEvent *event).
        """
        ...

    def hideEvent(self, a0: QtGui.QHideEvent) -> None:
        """
        https://doc.qt.io/qt-6/qquickwidget.html#hideEvent

        **[override virtual protected] void QQuickWidget::hideEvent(QHideEvent
        *)**

        Reimplements: **QWidget::hideEvent** (QHideEvent *event).
        """
        ...

    def showEvent(self, a0: QtGui.QShowEvent) -> None:
        """
        https://doc.qt.io/qt-6/qquickwidget.html#showEvent

        **[override virtual protected] void QQuickWidget::showEvent(QShowEvent
        *)**

        Reimplements: **QWidget::showEvent** (QShowEvent *event).
        """
        ...

    def mouseDoubleClickEvent(self, a0: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qquickwidget.html#mouseDoubleClickEvent

        **[override virtual protected] void
        QQuickWidget::mouseDoubleClickEvent(QMouseEvent * e )**

        Reimplements: **QWidget::mouseDoubleClickEvent** (QMouseEvent *event).
        """
        ...

    def mouseMoveEvent(self, a0: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qquickwidget.html#mouseMoveEvent

        **[override virtual protected] void
        QQuickWidget::mouseMoveEvent(QMouseEvent * e )**

        Reimplements: **QWidget::mouseMoveEvent** (QMouseEvent *event).
        """
        ...

    def mouseReleaseEvent(self, a0: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qquickwidget.html#mouseReleaseEvent

        **[override virtual protected] void
        QQuickWidget::mouseReleaseEvent(QMouseEvent * e )**

        Reimplements: **QWidget::mouseReleaseEvent** (QMouseEvent *event).
        """
        ...

    def mousePressEvent(self, a0: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qquickwidget.html#mousePressEvent

        **[override virtual protected] void
        QQuickWidget::mousePressEvent(QMouseEvent * e )**

        Reimplements: **QWidget::mousePressEvent** (QMouseEvent *event).
        """
        ...

    def keyReleaseEvent(self, a0: QtGui.QKeyEvent) -> None:
        """
        https://doc.qt.io/qt-6/qquickwidget.html#keyReleaseEvent

        **[override virtual protected] void
        QQuickWidget::keyReleaseEvent(QKeyEvent * e )**

        Reimplements: **QWidget::keyReleaseEvent** (QKeyEvent *event).
        """
        ...

    def keyPressEvent(self, a0: QtGui.QKeyEvent) -> None:
        """
        https://doc.qt.io/qt-6/qquickwidget.html#keyPressEvent

        **[override virtual protected] void
        QQuickWidget::keyPressEvent(QKeyEvent * e )**

        Reimplements: **QWidget::keyPressEvent** (QKeyEvent *event).
        """
        ...

    def timerEvent(self, a0: QtCore.QTimerEvent) -> None:
        ...

    def resizeEvent(self, a0: QtGui.QResizeEvent) -> None:
        ...

    def setSource(self, a0: QtCore.QUrl) -> None:
        """
        https://doc.qt.io/qt-6/qquickwidget.html#setSource

        **[slot] void QQuickWidget::setSource(const QUrl & url )**

        Sets the source to the **url** , loads the QML component and
        instantiates it.

        Ensure that the URL provided is full and correct, in particular, use
        **QUrl::fromLocalFile** () when loading a file from the local
        filesystem.

        Calling this method multiple times with the same URL will result in the
        QML component being reinstantiated.

        **Note:** Setter function for property **source** .

        **See also** **source** ().
        """
        ...

    def format(self) -> QtGui.QSurfaceFormat:
        """
        https://doc.qt.io/qt-6/qquickwidget.html#format

        **QSurfaceFormat QQuickWidget::format() const**

        Returns the actual surface format.

        If the widget has not yet been shown, the requested format is returned.

        **See also** **setFormat** ().
        """
        ...

    def setFormat(self, format: QtGui.QSurfaceFormat) -> None:
        """
        https://doc.qt.io/qt-6/qquickwidget.html#setFormat

        **void QQuickWidget::setFormat(const QSurfaceFormat & format )**

        Sets the surface **format** for the context and offscreen surface used
        by this widget.

        Call this function when there is a need to request a context for a given
        OpenGL version or profile. The sizes for depth, stencil and alpha
        buffers are taken care of automatically and there is no need to request
        those explicitly.

        **See also** **QWindow::setFormat** (), **QWindow::format** (), and
        **format** ().
        """
        ...

    def initialSize(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qquickwidget.html#initialSize

        **QSize QQuickWidget::initialSize() const**

        Returns the initial size of the root object.

        If **resizeMode**  is **SizeRootObjectToView** , the root object will be
        resized to the size of the view. This function returns the size of the
        root object before it was resized.
        """
        ...

    def sizeHint(self) -> QtCore.QSize:
        ...

    def errors(self) -> typing.List[QtQml.QQmlError]:
        """
        https://doc.qt.io/qt-6/qquickwidget.html#errors

        **QList<QQmlError> QQuickWidget::errors() const**

        Return the list of errors that occurred during the last compile or
        create operation. When the status is not **Error** , an empty list is
        returned.

        **See also** **status** .
        """
        ...

    def status(self) -> "QQuickWidget.Status":
        """
        https://doc.qt.io/qt-6/qquickwidget.html#status-prop

        **[read-only] status : const Status**

        The component's current **status** .

        **Access functions:**

        QQuickWidget::Status **status** () const

        **Notifier signal:**

        void ****statusChanged** ** (QQuickWidget::Status **status** )

        **Member Function Documentation**
        """
        ...

    def setResizeMode(self, a0: "QQuickWidget.ResizeMode") -> None:
        """
        https://doc.qt.io/qt-6/qquickwidget.html#resizeMode-prop

        **resizeMode : ResizeMode**

        Determines whether the view should resize the window contents.

        If this property is set to **SizeViewToRootObject**  (the default), the
        view resizes to the size of the root item in the QML.

        If this property is set to **SizeRootObjectToView** , the view will
        automatically resize the root item to the size of the view.

        Regardless of this property, the sizeHint of the view is the initial
        size of the root item. Note though that since QML may load dynamically,
        that size may change.

        **Access functions:**

        QQuickWidget::ResizeMode **resizeMode** () const
        void
        **setResizeMode** (QQuickWidget::ResizeMode)

        **See also** **initialSize** ().
        """
        ...

    def resizeMode(self) -> "QQuickWidget.ResizeMode":
        """
        https://doc.qt.io/qt-6/qquickwidget.html#resizeMode-prop

        **resizeMode : ResizeMode**

        Determines whether the view should resize the window contents.

        If this property is set to **SizeViewToRootObject**  (the default), the
        view resizes to the size of the root item in the QML.

        If this property is set to **SizeRootObjectToView** , the view will
        automatically resize the root item to the size of the view.

        Regardless of this property, the sizeHint of the view is the initial
        size of the root item. Note though that since QML may load dynamically,
        that size may change.

        **Access functions:**

        QQuickWidget::ResizeMode **resizeMode** () const
        void
        **setResizeMode** (QQuickWidget::ResizeMode)

        **See also** **initialSize** ().
        """
        ...

    def rootObject(self) -> QtQuick.QQuickItem:
        """
        https://doc.qt.io/qt-6/qquickwidget.html#rootObject

        **QQuickItem *QQuickWidget::rootObject() const**

        Returns the view's root **item** . Can be null when **setSource** () has
        not been called, if it was called with broken **QtQuick**  code or while
        the **QtQuick**  contents are being created.
        """
        ...

    def rootContext(self) -> QtQml.QQmlContext:
        """
        https://doc.qt.io/qt-6/qquickwidget.html#rootContext

        **QQmlContext *QQuickWidget::rootContext() const**

        This function returns the root of the context hierarchy. Each QML
        component is instantiated in a **QQmlContext** . **QQmlContext** 's are
        essential for passing data to QML components. In QML, contexts are
        arranged hierarchically and this hierarchy is managed by the
        **QQmlEngine** .
        """
        ...

    def engine(self) -> QtQml.QQmlEngine:
        """
        https://doc.qt.io/qt-6/qquickwidget.html#engine

        **QQmlEngine *QQuickWidget::engine() const**

        Returns a pointer to the **QQmlEngine**  used for instantiating QML
        Components.
        """
        ...

    def source(self) -> QtCore.QUrl:
        """
        https://doc.qt.io/qt-6/qquickwidget.html#source

        **QUrl QQuickWidget::source() const**

        Returns the source URL, if set.

        **Note:** Getter function for property source.

        **See also** **setSource** ().
        """
        ...

    @property
    def sceneGraphError(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qquickwidget.html#sceneGraphError

        **[signal] void
        QQuickWidget::sceneGraphError(QQuickWindow::SceneGraphError error ,
        const QString & message )**

        This signal is emitted when an **error** occurred during scene graph
        initialization.

        Applications should connect to this signal if they wish to handle
        errors, like OpenGL context creation failures, in a custom way. When no
        slot is connected to the signal, the behavior will be different: Quick
        will print the **message** , or show a message box, and terminate the
        application.

        This signal will be emitted from the GUI thread.

        **See also** **QQuickWindow::sceneGraphError** ().
        """
        ...

    @property
    def statusChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qquickwidget.html#statusChanged

        **[signal] void QQuickWidget::statusChanged(QQuickWidget::Status status
        )**

        This signal is emitted when the component's current **status** changes.

        **Note:** Notifier signal for property **status** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import PyQt6.sip
from PyQt6 import QtCore


class QHelpContentItem(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qhelpcontentitem.html

    **Detailed Description**
    """

    def childPosition(self, child: "QHelpContentItem") -> int:
        """
        https://doc.qt.io/qt-6/qhelpcontentitem.html#childPosition

        **int QHelpContentItem::childPosition(QHelpContentItem * child ) const**

        Returns the position of a given **child**.
        """
        ...

    def parent(self) -> "QHelpContentItem":
        """
        https://doc.qt.io/qt-6/qhelpcontentitem.html#parent

        **QHelpContentItem *QHelpContentItem::parent() const**

        Returns the parent content item.
        """
        ...

    def row(self) -> int:
        """
        https://doc.qt.io/qt-6/qhelpcontentitem.html#row

        **int QHelpContentItem::row() const**

        Returns the row of this item from its parents view.
        """
        ...

    def url(self) -> QtCore.QUrl:
        """
        https://doc.qt.io/qt-6/qhelpcontentitem.html#url

        **QUrl QHelpContentItem::url() const**

        Returns the URL of this content item.
        """
        ...

    def title(self) -> str:
        """
        https://doc.qt.io/qt-6/qhelpcontentitem.html#title

        **QString QHelpContentItem::title() const**

        Returns the title of the content item.
        """
        ...

    def childCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qhelpcontentitem.html#childCount

        **int QHelpContentItem::childCount() const**

        Returns the number of child items.
        """
        ...

    def child(self, row: int) -> "QHelpContentItem":
        """
        https://doc.qt.io/qt-6/qhelpcontentitem.html#child

        **QHelpContentItem *QHelpContentItem::child(int row ) const**

        Returns the child of the content item in the give **row**.

        **See also** **parent** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QAbstractGraphicsShapeItem(QGraphicsItem):
    """
    https://doc.qt.io/qt-6/qabstractgraphicsshapeitem.html

    **Detailed Description**

    This class does not fully implement an item by itself; in particular, it
    does not implement **boundingRect** () and **paint** (), which are inherited
    by **QGraphicsItem** .

    You can subclass this item to provide a simple base implementation of
    accessors for the item's pen and brush.

    **See also** **QGraphicsRectItem** , **QGraphicsEllipseItem** ,
    **QGraphicsPathItem** , **QGraphicsPolygonItem** , **QGraphicsTextItem** ,
    **QGraphicsLineItem** , **QGraphicsPixmapItem** , and **Graphics View
    Framework** .
    """

    def __init__(self, parent: typing.Optional[QGraphicsItem] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qabstractgraphicsshapeitem.html#QAbstractGraphics
        ShapeItem

        **QAbstractGraphicsShapeItem::QAbstractGraphicsShapeItem(QGraphicsItem *
        parent = nullptr)**

        Constructs a QAbstractGraphicsShapeItem. **parent** is passed to
        **QGraphicsItem** 's constructor.
        """
        ...

    def opaqueArea(self) -> QtGui.QPainterPath:
        """
        https://doc.qt.io/qt-6/qabstractgraphicsshapeitem.html#opaqueArea

        **[override virtual] QPainterPath
        QAbstractGraphicsShapeItem::opaqueArea() const**

        Reimplements: **QGraphicsItem::opaqueArea() const** .
        """
        ...

    def isObscuredBy(self, item: QGraphicsItem) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractgraphicsshapeitem.html#isObscuredBy

        **[override virtual] bool QAbstractGraphicsShapeItem::isObscuredBy(const
        QGraphicsItem * item ) const**

        Reimplements: **QGraphicsItem::isObscuredBy(const QGraphicsItem *item)
        const** .
        """
        ...

    def setBrush(
        self,
        brush: typing.Union[
            QtGui.QBrush, QtGui.QColor, QtCore.Qt.GlobalColor, int, QtGui.QGradient
        ],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qabstractgraphicsshapeitem.html#setBrush

        **void QAbstractGraphicsShapeItem::setBrush(const QBrush & brush )**

        Sets the item's brush to **brush**.

        The item's brush is used to fill the item.

        If you use a brush with a **QGradient** , the gradient is relative to
        the item's coordinate system.

        **See also** **brush** ().
        """
        ...

    def brush(self) -> QtGui.QBrush:
        """
        https://doc.qt.io/qt-6/qabstractgraphicsshapeitem.html#brush

        **QBrush QAbstractGraphicsShapeItem::brush() const**

        Returns the item's brush, or an empty brush if no brush has been set.

        **See also** **setBrush** ().
        """
        ...

    def setPen(
        self,
        pen: typing.Union[
            QtGui.QPen, QtGui.QColor, QtCore.Qt.GlobalColor, int, QtGui.QGradient
        ],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qabstractgraphicsshapeitem.html#setPen

        **void QAbstractGraphicsShapeItem::setPen(const QPen & pen )**

        Sets the pen for this item to **pen**.

        The pen is used to draw the item's outline.

        **See also** **pen** ().
        """
        ...

    def pen(self) -> QtGui.QPen:
        """
        https://doc.qt.io/qt-6/qabstractgraphicsshapeitem.html#pen

        **QPen QAbstractGraphicsShapeItem::pen() const**

        Returns the item's pen. If no pen has been set, this function returns
        QPen(), a default black solid line pen with 1 width.

        **See also** **setPen** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtNetwork import *


class QOcspResponse(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qocspresponse.html

    **Detailed Description**

    The QOcspResponse class represents the revocation status of a server's
    certificate, received by the client-side socket during the TLS handshake.
    **QSslSocket**  must be configured with OCSP stapling enabled.

    **See also** **QSslSocket** , **QSslSocket::ocspResponses** (),
    **certificateStatus** (), **revocationReason** (), **responder** (),
    **subject** (), **QOcspCertificateStatus** , **QOcspRevocationReason** ,
    **QSslConfiguration::setOcspStaplingEnabled** (),
    **QSslConfiguration::ocspStaplingEnabled** (), and
    **QSslConfiguration::peerCertificate** ().
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qocspresponse.html#QOcspResponse

        **[since 5.13] QOcspResponse::QOcspResponse()**

        Creates a new response with status **QOcspCertificateStatus::Unknown**
        and revocation reason **QOcspRevocationReason::None** .

        This function was introduced in Qt 5.13.

        **See also** **QOcspCertificateStatus** .
        """
        ...

    @typing.overload
    def __init__(self, other: "QOcspResponse") -> None:
        """
        https://doc.qt.io/qt-6/qocspresponse.html#QOcspResponse-1

        **[since 5.13] QOcspResponse::QOcspResponse(const QOcspResponse & other
        )**

        Copy-constructs a QOcspResponse instance.

        This function was introduced in Qt 5.13.
        """
        ...

    def __hash__(self) -> int:
        ...

    def swap(self, other: "QOcspResponse") -> None:
        """
        https://doc.qt.io/qt-6/qocspresponse.html#swap

        **[since 5.13] void QOcspResponse::swap(QOcspResponse & other )**

        Swaps this response with **other**.

        This function was introduced in Qt 5.13.
        """
        ...

    def subject(self) -> "QSslCertificate":
        """
        https://doc.qt.io/qt-6/qocspresponse.html#subject

        **[since 5.13] QSslCertificate QOcspResponse::subject() const**

        This function returns a certificate, for which this response was issued.

        This function was introduced in Qt 5.13.
        """
        ...

    def responder(self) -> "QSslCertificate":
        """
        https://doc.qt.io/qt-6/qocspresponse.html#responder

        **[since 5.13] class QSslCertificate QOcspResponse::responder() const**

        This function returns a certificate used to sign OCSP response.

        This function was introduced in Qt 5.13.
        """
        ...

    def revocationReason(self) -> QOcspRevocationReason:
        """
        https://doc.qt.io/qt-6/qocspresponse.html#revocationReason

        **[since 5.13] QOcspRevocationReason QOcspResponse::revocationReason()
        const**

        Returns the reason for revocation.

        This function was introduced in Qt 5.13.
        """
        ...

    def certificateStatus(self) -> QOcspCertificateStatus:
        """
        https://doc.qt.io/qt-6/qocspresponse.html#certificateStatus

        **[since 5.13] QOcspCertificateStatus QOcspResponse::certificateStatus()
        const**

        Returns the certificate status.

        This function was introduced in Qt 5.13.

        **See also** **QOcspCertificateStatus** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QCursor(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qcursor.html

    **Detailed Description**

    This class is mainly used to create mouse cursors that are associated with
    particular widgets and to get and set the position of the mouse cursor.

    Qt has a number of standard cursor shapes, but you can also make custom
    cursor shapes based on a **QBitmap** , a mask and a hotspot.

    To associate a cursor with a widget, use **QWidget::setCursor** (). To
    associate a cursor with all widgets (normally for a short period of time),
    use **QGuiApplication::setOverrideCursor** ().

    To set a cursor shape use **QCursor::setShape** () or use the QCursor
    constructor which takes the shape as argument, or you can use one of the
    predefined cursors defined in the **Qt::CursorShape**  enum.

    If you want to create a cursor with your own bitmap, either use the QCursor
    constructor which takes a bitmap and a mask or the constructor which takes a
    pixmap as arguments.

    To set or get the position of the mouse cursor use the static methods
    **QCursor::pos** () and **QCursor::setPos** ().

    **Note:** It is possible to create a QCursor before **QGuiApplication** ,
    but it is not useful except as a place-holder for a real QCursor created
    after **QGuiApplication** . Attempting to use a QCursor that was created
    before **QGuiApplication**  will result in a crash.

    **A Note for X11 Users**

    On X11, Qt supports the **Xcursor**  library, which allows for full color
    icon themes. The table below shows the cursor name used for each
    **Qt::CursorShape**  value. If a cursor cannot be found using the name shown
    below, a standard X11 cursor will be used instead. Note: X11 does not
    provide appropriate cursors for all possible **Qt::CursorShape**  values. It
    is possible that some cursors will be taken from the Xcursor theme, while
    others will use an internal bitmap cursor.

    Shape**Qt::CursorShape**  ValueCursor NameShape**Qt::CursorShape**
    ValueCursor Name
    ![](images/cursor-arrow.png)**Qt::ArrowCursor**
    `left_ptr`![](images/cursor-sizev.png)**Qt::SizeVerCursor** `size_ver`
    ![](images/cursor-uparrow.png)**Qt::UpArrowCursor**
    `up_arrow`![](images/cursor-sizeh.png)**Qt::SizeHorCursor** `size_hor`
    ![](images/cursor-cross.png)**Qt::CrossCursor** `cross`![](images/cursor-
    sizeb.png)**Qt::SizeBDiagCursor** `size_bdiag`
    ![](images/cursor-
    ibeam.png)**Qt::IBeamCursor** `ibeam`![](images/cursor-
    sizef.png)**Qt::SizeFDiagCursor** `size_fdiag`
    ![](images/cursor-
    wait.png)**Qt::WaitCursor** `wait`![](images/cursor-
    sizeall.png)**Qt::SizeAllCursor** `size_all`
    ![](images/cursor-
    busy.png)**Qt::BusyCursor** `left_ptr_watch`![](images/cursor-
    vsplit.png)**Qt::SplitVCursor** `split_v`
    ![](images/cursor-
    forbidden.png)**Qt::ForbiddenCursor** `forbidden`![](images/cursor-
    hsplit.png)**Qt::SplitHCursor** `split_h`
    ![](images/cursor-
    hand.png)**Qt::PointingHandCursor** `pointing_hand`![](images/cursor-
    openhand.png)**Qt::OpenHandCursor** `openhand`
    ![](images/cursor-
    whatsthis.png)**Qt::WhatsThisCursor** `whats_this`![](images/cursor-
    closedhand.png)**Qt::ClosedHandCursor** `closedhand`
    **Qt::DragMoveCursor** `dnd-move` or `move`**Qt::DragCopyCursor** `dnd-copy`
    or `copy`
    **Qt::DragLinkCursor** `dnd-link` or `link`

    **See also** **QWidget**  and **GUI Design Handbook: Cursors** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qcursor.html#QCursor

        **QCursor::QCursor()**

        Constructs a cursor with the default arrow shape.
        """
        ...

    @typing.overload
    def __init__(
        self, bitmap: QBitmap, mask: QBitmap, hotX: int = ..., hotY: int = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qcursor.html#QCursor-1

        **QCursor::QCursor(Qt::CursorShape shape )**

        Constructs a cursor with the specified **shape**.

        See **Qt::CursorShape**  for a list of shapes.

        **See also** **setShape** ().
        """
        ...

    @typing.overload
    def __init__(self, pixmap: QPixmap, hotX: int = ..., hotY: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qcursor.html#QCursor-2

        **QCursor::QCursor(const QBitmap & bitmap , const QBitmap & mask , int
        hotX = -1, int hotY = -1)**

        Constructs a custom bitmap cursor.

        **bitmap** and **mask** make up the bitmap. **hotX** and **hotY** define
        the cursor's hot spot.

        If **hotX** is negative, it is set to the `bitmap().width()/2`. If
        **hotY** is negative, it is set to the `bitmap().height()/2`.

        The cursor **bitmap** (B) and **mask** (M) bits are combined like this:

        * B=1 and M=1 gives black.
          * B=0 and M=1 gives white.
          * B=0 and M=0
        gives transparent.
          * B=1 and M=0 gives an XOR'd result under Windows,
        undefined results on all other platforms.

        Use the global Qt color **Qt::color0**  to draw 0-pixels and
        **Qt::color1**  to draw 1-pixels in the bitmaps.

        Valid cursor sizes depend on the display hardware (or the underlying
        window system). We recommend using 32 x 32 cursors, because this size is
        supported on all platforms. Some platforms also support 16 x 16, 48 x
        48, and 64 x 64 cursors.

        **See also** **QBitmap::QBitmap** () and **QBitmap::setMask** ().
        """
        ...

    @typing.overload
    def __init__(self, cursor: typing.Union["QCursor", QtCore.Qt.CursorShape]) -> None:
        """
        https://doc.qt.io/qt-6/qcursor.html#QCursor-3

        **QCursor::QCursor(const QPixmap & pixmap , int hotX = -1, int hotY =
        -1)**

        Constructs a custom pixmap cursor.

        **pixmap** is the image. It is usual to give it a mask (set using
        **QPixmap::setMask** ()). **hotX** and **hotY** define the cursor's hot
        spot.

        If **hotX** is negative, it is set to the `pixmap().width()/2`. If
        **hotY** is negative, it is set to the `pixmap().height()/2`.

        Valid cursor sizes depend on the display hardware (or the underlying
        window system). We recommend using 32 x 32 cursors, because this size is
        supported on all platforms. Some platforms also support 16 x 16, 48 x
        48, and 64 x 64 cursors.

        **See also** **QPixmap::QPixmap** () and **QPixmap::setMask** ().
        """
        ...

    @typing.overload
    def __init__(self, variant: typing.Any) -> None:
        """
        https://doc.qt.io/qt-6/qcursor.html#QCursor-4

        **QCursor::QCursor(const QCursor & c )**

        Constructs a copy of the cursor **c**.
        """
        ...

    def swap(self, other: typing.Union["QCursor", QtCore.Qt.CursorShape]) -> None:
        """
        https://doc.qt.io/qt-6/qcursor.html#swap

        **[since 5.7] void QCursor::swap(QCursor & other )**

        Swaps this cursor with the **other** cursor.

        This function was introduced in Qt 5.7.
        """
        ...

    @typing.overload
    @staticmethod
    def setPos(x: int, y: int) -> None:
        """
        https://doc.qt.io/qt-6/qcursor.html#setPos

        **[static] void QCursor::setPos(int x , int y )**

        Moves the cursor (hot spot) of the primary screen to the global screen
        position ( **x** , **y** ).

        You can call **QWidget::mapToGlobal** () to translate widget coordinates
        to global screen coordinates.

        **See also** **pos** (), **QWidget::mapFromGlobal** (),
        **QWidget::mapToGlobal** (), and **QGuiApplication::primaryScreen** ().
        """
        ...

    @typing.overload
    @staticmethod
    def setPos(p: QtCore.QPoint) -> None:
        """
        https://doc.qt.io/qt-6/qcursor.html#setPos-1

        **[static] void QCursor::setPos(QScreen * screen , int x , int y )**

        Moves the cursor (hot spot) of the **screen** to the global screen
        position ( **x** , **y** ).

        You can call **QWidget::mapToGlobal** () to translate widget coordinates
        to global screen coordinates.

        **Note:** Calling this function results in changing the cursor position
        through the windowing system. The windowing system will typically
        respond by sending mouse events to the application's window. This means
        that the usage of this function should be avoided in unit tests and
        everywhere where fake mouse events are being injected via
        QWindowSystemInterface because the windowing system's mouse state (with
        regards to buttons for example) may not match the state in the
        application-generated events.

        **Note:** On platforms where there is no windowing system or cursors are
        not available, this function may do nothing.

        **See also** **pos** (), **QWidget::mapFromGlobal** (), and
        **QWidget::mapToGlobal** ().
        """
        ...

    @typing.overload
    @staticmethod
    def setPos(screen: "QScreen", x: int, y: int) -> None:
        """
        https://doc.qt.io/qt-6/qcursor.html#setPos-2

        **[static] void QCursor::setPos(const QPoint & p )**

        This is an overloaded function.

        Moves the cursor (hot spot) to the global screen position at point
        **p**.
        """
        ...

    @typing.overload
    @staticmethod
    def setPos(screen: "QScreen", p: QtCore.QPoint) -> None:
        """
        https://doc.qt.io/qt-6/qcursor.html#setPos-3

        **[static] void QCursor::setPos(QScreen * screen , const QPoint & p )**

        This is an overloaded function.

        Moves the cursor (hot spot) to the global screen position of the
        **screen** at point **p**.
        """
        ...

    @typing.overload
    @staticmethod
    def pos() -> QtCore.QPoint:
        """
        https://doc.qt.io/qt-6/qcursor.html#pos

        **[static] QPoint QCursor::pos()**

        Returns the position of the cursor (hot spot) of the primary screen in
        global screen coordinates.

        You can call **QWidget::mapFromGlobal** () to translate it to widget
        coordinates.

        **Note:** The position is queried from the windowing system. If mouse
        events are generated via other means (e.g., via QWindowSystemInterface
        in a unit test), those fake mouse moves will not be reflected in the
        returned value.

        **Note:** On platforms where there is no windowing system or cursors are
        not available, the returned position is based on the mouse move events
        generated via QWindowSystemInterface.

        **See also** **setPos** (), **QWidget::mapFromGlobal** (),
        **QWidget::mapToGlobal** (), and **QGuiApplication::primaryScreen** ().
        """
        ...

    @typing.overload
    @staticmethod
    def pos(screen: "QScreen") -> QtCore.QPoint:
        """
        https://doc.qt.io/qt-6/qcursor.html#pos-1

        **[static] QPoint QCursor::pos(const QScreen * screen )**

        Returns the position of the cursor (hot spot) of the **screen** in
        global screen coordinates.

        You can call **QWidget::mapFromGlobal** () to translate it to widget
        coordinates.

        **See also** **setPos** (), **QWidget::mapFromGlobal** (), and
        **QWidget::mapToGlobal** ().
        """
        ...

    def hotSpot(self) -> QtCore.QPoint:
        """
        https://doc.qt.io/qt-6/qcursor.html#hotSpot

        **QPoint QCursor::hotSpot() const**

        Returns the cursor hot spot, or (0, 0) if it is one of the standard
        cursors.
        """
        ...

    def pixmap(self) -> QPixmap:
        """
        https://doc.qt.io/qt-6/qcursor.html#pixmap

        **QPixmap QCursor::pixmap() const**

        Returns the cursor pixmap. This is only valid if the cursor is a pixmap
        cursor.
        """
        ...

    def mask(self) -> QBitmap:
        """
        https://doc.qt.io/qt-6/qcursor.html#mask-1

        **QBitmap QCursor::mask() const**

        Returns the cursor bitmap mask, or a null bitmap if it is one of the
        standard cursors.
        """
        ...

    def bitmap(self) -> QBitmap:
        """
        https://doc.qt.io/qt-6/qcursor.html#bitmap-1

        **QBitmap QCursor::bitmap() const**

        Returns the cursor bitmap, or a null bitmap if it is one of the standard
        cursors.
        """
        ...

    def setShape(self, newShape: QtCore.Qt.CursorShape) -> None:
        """
        https://doc.qt.io/qt-6/qcursor.html#setShape

        **void QCursor::setShape(Qt::CursorShape shape )**

        Sets the cursor to the shape identified by **shape**.

        See **Qt::CursorShape**  for the list of cursor shapes.

        **See also** **shape** ().
        """
        ...

    def shape(self) -> QtCore.Qt.CursorShape:
        """
        https://doc.qt.io/qt-6/qcursor.html#shape

        **Qt::CursorShape QCursor::shape() const**

        Returns the cursor shape identifier.

        **See also** **setShape** ().
        """
        ...
